# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.edit_root_json_schema import EditRootJsonSchema
from .edit_create_async_request_config_advanced_options import EditCreateAsyncRequestConfigAdvancedOptions


class EditCreateAsyncRequestConfig(UncheckedBaseModel):
    """
    Configuration for the edit operation. Field values should be specified using `extend_edit:value` on each field in the schema.
    """

    schema_: typing_extensions.Annotated[typing.Optional[EditRootJsonSchema], FieldMetadata(alias="schema")] = (
        pydantic.Field(alias="schema", default=None)
    )
    instructions: typing.Optional[str] = pydantic.Field(default=None)
    """
    Custom instructions for the edit operation.
    """

    advanced_options: typing_extensions.Annotated[
        typing.Optional[EditCreateAsyncRequestConfigAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = pydantic.Field(alias="advancedOptions", default=None)
    """
    Advanced options for the edit operation.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(EditCreateAsyncRequestConfig)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        ApiVersionEnum,
        ArrayStrategy,
        ArrayStrategyType,
        BadRequestErrorBody,
        BadRequestErrorBodyCode,
        BaseMetrics,
        BatchProcessorRun,
        BatchProcessorRunMetrics,
        BatchProcessorRunOptions,
        BatchProcessorRunSource,
        BatchProcessorRunStatus,
        BatchWorkflowRunFileInput,
        Block,
        BlockBoundingBox,
        BlockDetails,
        BlockMetadata,
        BlockMetadataPage,
        BlockPolygonItem,
        BlockType,
        Chunk,
        ChunkMetadata,
        ChunkMetadataPageRange,
        ChunkType,
        Citation,
        Classification,
        ClassificationAdvancedOptions,
        ClassificationAdvancedOptionsContext,
        ClassificationConfig,
        ClassificationConfigBaseProcessor,
        ClassificationFieldMetrics,
        ClassifierOutput,
        ClassifyMetrics,
        ClassifyOptimizerOptions,
        DocumentProcessorRunCredits,
        EditBoundingBox,
        EditError,
        EditErrorCode,
        EditJsonSchema,
        EditJsonSchemaExtendEditFieldType,
        EditObjectJsonSchema,
        EditRootJsonSchema,
        EditRun,
        EditRunConfig,
        EditRunConfigAdvancedOptions,
        EditRunEditedFile,
        EditRunMetrics,
        EditRunStatus,
        EditRunStatusStatus,
        EditRunUsage,
        EditTextOptions,
        EmptyBlockDetails,
        Enum,
        EnumOption,
        Error,
        EvaluationSet,
        EvaluationSetItem,
        ExcelSheetRange,
        ExtendError,
        ExtractChunkingOptions,
        ExtractChunkingOptionsChunkSelectionStrategy,
        ExtractChunkingOptionsChunkingStrategy,
        ExtractMetrics,
        ExtractMetricsFieldMetrics,
        ExtractOptimizerOptions,
        ExtractionAdvancedOptions,
        ExtractionAdvancedOptionsArrayCitationStrategy,
        ExtractionAdvancedOptionsExcelSheetSelectionStrategy,
        ExtractionAdvancedOptionsReviewAgent,
        ExtractionConfig,
        ExtractionConfigBaseProcessor,
        ExtractionField,
        ExtractionFieldMetrics,
        ExtractionFieldResult,
        ExtractionFieldResultReference,
        ExtractionFieldResultReferenceBoundingBoxesItem,
        ExtractionFieldResultType,
        ExtractionFieldType,
        ExtractionOutput,
        ExtractionOutputEdits,
        FieldsArrayOutput,
        FigureDetails,
        FigureDetailsFigureType,
        File,
        FileContents,
        FileContentsPagesItem,
        FileContentsSheetsItem,
        FileCredits,
        FileMetadata,
        FileMetadataParentSplit,
        FileType,
        Insight,
        InsightType,
        JsonObject,
        JsonOutput,
        JsonOutputMetadataValue,
        JsonOutputMetadataValueCitationsItem,
        JsonOutputMetadataValueCitationsItemPolygonItem,
        ListProcessorsProcessor,
        ListProcessorsProcessorVersion,
        ListProcessorsResponse,
        MaxPageSize,
        NextPageToken,
        OptimizerBatchProcessorRunResult,
        OptimizerBatchProcessorRunResultProcessorConfig,
        OptimizerBatchProcessorRunResultProcessorConfig_Classify,
        OptimizerBatchProcessorRunResultProcessorConfig_Extract,
        OptimizerRun,
        OptimizerRunAgentType,
        OptimizerRunMetrics,
        OptimizerRunMetricsFieldsItem,
        OptimizerRunStatus,
        OutputMetadata,
        OutputMetadataValue,
        PageRanges,
        PageRangesItem,
        ParseAsyncRequestFile,
        ParseConfig,
        ParseConfigAdvancedOptions,
        ParseConfigBlockOptions,
        ParseConfigBlockOptionsFigures,
        ParseConfigBlockOptionsTables,
        ParseConfigBlockOptionsTablesTargetFormat,
        ParseConfigBlockOptionsText,
        ParseConfigChunkingStrategy,
        ParseConfigChunkingStrategyOptions,
        ParseConfigChunkingStrategyType,
        ParseConfigTarget,
        ParseError,
        ParseErrorCode,
        ParseRequestFile,
        ParseRequestResponseType,
        ParserRun,
        ParserRunCredits,
        ParserRunMetrics,
        ParserRunStatus,
        ParserRunStatusEnum,
        ParserRunStatusStatus,
        Polygon,
        Processor,
        ProcessorId,
        ProcessorOutput,
        ProcessorRun,
        ProcessorRunConfig,
        ProcessorRunConfig_Classify,
        ProcessorRunConfig_Extract,
        ProcessorRunConfig_Splitter,
        ProcessorRunFileInput,
        ProcessorRunMergedProcessorsItem,
        ProcessorRunSummary,
        ProcessorRunSummaryType,
        ProcessorRunType,
        ProcessorStatus,
        ProcessorType,
        ProcessorVersion,
        ProcessorVersionConfig,
        ProcessorVersionConfig_Classify,
        ProcessorVersionConfig_Extract,
        ProcessorVersionConfig_Splitter,
        ProvidedClassifierOutput,
        ProvidedExtractionFieldResult,
        ProvidedExtractionFieldResultType,
        ProvidedExtractionOutput,
        ProvidedFieldsArrayOutput,
        ProvidedJsonOutput,
        ProvidedProcessorOutput,
        ProvidedSplitterOutput,
        ProvidedSplitterOutputSplitsItem,
        SortByEnum,
        SortDirEnum,
        SplitterAdvancedOptions,
        SplitterAdvancedOptionsSplitMethod,
        SplitterConfig,
        SplitterConfigBaseProcessor,
        SplitterMetrics,
        SplitterOutput,
        SplitterOutputSplitsItem,
        StepRun,
        StepRunOutput,
        StepRunOutputRulesItem,
        StepRunOutputRulesItemFailureReason,
        StepRunStatus,
        StepRunStep,
        StepRunStepType,
        TableCellDetails,
        TableDetails,
        TooManyRequestsErrorBody,
        WebhookEvent,
        WebhookEventEventType,
        WebhookEventPayload,
        WebhookEventProcessor,
        WebhookEventProcessorEventType,
        WebhookEventProcessorRun,
        WebhookEventProcessorRunEventType,
        WebhookEventProcessorVersion,
        WebhookEventWorkflow,
        WebhookEventWorkflowEventType,
        WebhookEventWorkflowRun,
        WebhookEventWorkflowRunEventType,
        Workflow,
        WorkflowRun,
        WorkflowRunCredits,
        WorkflowRunFileInput,
        WorkflowRunFileInputOutputsItem,
        WorkflowRunSummary,
        WorkflowStatus,
    )
    from .errors import (
        BadRequestError,
        InternalServerError,
        NotFoundError,
        PaymentRequiredError,
        TooManyRequestsError,
        UnauthorizedError,
        UnprocessableEntityError,
    )
    from . import (
        batch_processor_run,
        batch_workflow_run,
        edit,
        evaluation_set,
        evaluation_set_item,
        file,
        parser_run,
        processor,
        processor_run,
        processor_version,
        workflow,
        workflow_run,
        workflow_run_output,
    )
    from .batch_processor_run import BatchProcessorRunGetResponse
    from .batch_workflow_run import BatchWorkflowRunCreateRequestInputsItem, BatchWorkflowRunCreateResponse
    from .client import AsyncExtend, Extend
    from .edit import (
        EditCreateAsyncRequestConfig,
        EditCreateAsyncRequestConfigAdvancedOptions,
        EditCreateAsyncRequestFile,
        EditCreateRequestConfig,
        EditCreateRequestConfigAdvancedOptions,
        EditCreateRequestFile,
        EditDeleteResponse,
        EditGetResponse,
        EditGetResponseEditRun,
        EditGetResponseEditRun_EditRun,
        EditGetResponseEditRun_EditRunStatus,
    )
    from .environment import ExtendEnvironment
    from .evaluation_set import EvaluationSetCreateResponse, EvaluationSetGetResponse, EvaluationSetListResponse
    from .evaluation_set_item import (
        EvaluationSetItemCreateBatchRequestItemsItem,
        EvaluationSetItemCreateBatchResponse,
        EvaluationSetItemCreateResponse,
        EvaluationSetItemDeleteResponse,
        EvaluationSetItemListResponse,
        EvaluationSetItemUpdateResponse,
    )
    from .file import FileDeleteResponse, FileGetResponse, FileListResponse, FileUploadResponse
    from .parser_run import (
        ParserRunDeleteResponse,
        ParserRunGetRequestResponseType,
        ParserRunGetResponse,
        ParserRunGetResponseParserRun,
        ParserRunGetResponseParserRun_ParserRun,
        ParserRunGetResponseParserRun_ParserRunStatus,
    )
    from .processor import (
        ProcessorCreateRequestConfig,
        ProcessorCreateRequestConfig_Classify,
        ProcessorCreateRequestConfig_Extract,
        ProcessorCreateRequestConfig_Splitter,
        ProcessorCreateResponse,
        ProcessorListRequestSortBy,
        ProcessorListRequestSortDir,
        ProcessorUpdateRequestConfig,
        ProcessorUpdateRequestConfig_Classify,
        ProcessorUpdateRequestConfig_Extract,
        ProcessorUpdateRequestConfig_Splitter,
        ProcessorUpdateResponse,
    )
    from .processor_run import (
        ProcessorRunCancelResponse,
        ProcessorRunCreateRequestConfig,
        ProcessorRunCreateRequestConfig_Classify,
        ProcessorRunCreateRequestConfig_Extract,
        ProcessorRunCreateRequestConfig_Splitter,
        ProcessorRunCreateResponse,
        ProcessorRunDeleteResponse,
        ProcessorRunGetResponse,
        ProcessorRunListRequestSource,
        ProcessorRunListResponse,
    )
    from .processor_version import (
        ProcessorVersionCreateRequestConfig,
        ProcessorVersionCreateRequestConfig_Classify,
        ProcessorVersionCreateRequestConfig_Extract,
        ProcessorVersionCreateRequestConfig_Splitter,
        ProcessorVersionCreateRequestReleaseType,
        ProcessorVersionCreateResponse,
        ProcessorVersionGetResponse,
        ProcessorVersionListResponse,
    )
    from .version import __version__
    from .workflow import WorkflowCreateResponse
    from .workflow_run import (
        WorkflowRunCancelResponse,
        WorkflowRunCancelResponseWorkflowRun,
        WorkflowRunCreateResponse,
        WorkflowRunDeleteResponse,
        WorkflowRunGetResponse,
        WorkflowRunListResponse,
        WorkflowRunUpdateResponse,
    )
    from .workflow_run_output import WorkflowRunOutputUpdateResponse
_dynamic_imports: typing.Dict[str, str] = {
    "ApiVersionEnum": ".types",
    "ArrayStrategy": ".types",
    "ArrayStrategyType": ".types",
    "AsyncExtend": ".client",
    "BadRequestError": ".errors",
    "BadRequestErrorBody": ".types",
    "BadRequestErrorBodyCode": ".types",
    "BaseMetrics": ".types",
    "BatchProcessorRun": ".types",
    "BatchProcessorRunGetResponse": ".batch_processor_run",
    "BatchProcessorRunMetrics": ".types",
    "BatchProcessorRunOptions": ".types",
    "BatchProcessorRunSource": ".types",
    "BatchProcessorRunStatus": ".types",
    "BatchWorkflowRunCreateRequestInputsItem": ".batch_workflow_run",
    "BatchWorkflowRunCreateResponse": ".batch_workflow_run",
    "BatchWorkflowRunFileInput": ".types",
    "Block": ".types",
    "BlockBoundingBox": ".types",
    "BlockDetails": ".types",
    "BlockMetadata": ".types",
    "BlockMetadataPage": ".types",
    "BlockPolygonItem": ".types",
    "BlockType": ".types",
    "Chunk": ".types",
    "ChunkMetadata": ".types",
    "ChunkMetadataPageRange": ".types",
    "ChunkType": ".types",
    "Citation": ".types",
    "Classification": ".types",
    "ClassificationAdvancedOptions": ".types",
    "ClassificationAdvancedOptionsContext": ".types",
    "ClassificationConfig": ".types",
    "ClassificationConfigBaseProcessor": ".types",
    "ClassificationFieldMetrics": ".types",
    "ClassifierOutput": ".types",
    "ClassifyMetrics": ".types",
    "ClassifyOptimizerOptions": ".types",
    "DocumentProcessorRunCredits": ".types",
    "EditBoundingBox": ".types",
    "EditCreateAsyncRequestConfig": ".edit",
    "EditCreateAsyncRequestConfigAdvancedOptions": ".edit",
    "EditCreateAsyncRequestFile": ".edit",
    "EditCreateRequestConfig": ".edit",
    "EditCreateRequestConfigAdvancedOptions": ".edit",
    "EditCreateRequestFile": ".edit",
    "EditDeleteResponse": ".edit",
    "EditError": ".types",
    "EditErrorCode": ".types",
    "EditGetResponse": ".edit",
    "EditGetResponseEditRun": ".edit",
    "EditGetResponseEditRun_EditRun": ".edit",
    "EditGetResponseEditRun_EditRunStatus": ".edit",
    "EditJsonSchema": ".types",
    "EditJsonSchemaExtendEditFieldType": ".types",
    "EditObjectJsonSchema": ".types",
    "EditRootJsonSchema": ".types",
    "EditRun": ".types",
    "EditRunConfig": ".types",
    "EditRunConfigAdvancedOptions": ".types",
    "EditRunEditedFile": ".types",
    "EditRunMetrics": ".types",
    "EditRunStatus": ".types",
    "EditRunStatusStatus": ".types",
    "EditRunUsage": ".types",
    "EditTextOptions": ".types",
    "EmptyBlockDetails": ".types",
    "Enum": ".types",
    "EnumOption": ".types",
    "Error": ".types",
    "EvaluationSet": ".types",
    "EvaluationSetCreateResponse": ".evaluation_set",
    "EvaluationSetGetResponse": ".evaluation_set",
    "EvaluationSetItem": ".types",
    "EvaluationSetItemCreateBatchRequestItemsItem": ".evaluation_set_item",
    "EvaluationSetItemCreateBatchResponse": ".evaluation_set_item",
    "EvaluationSetItemCreateResponse": ".evaluation_set_item",
    "EvaluationSetItemDeleteResponse": ".evaluation_set_item",
    "EvaluationSetItemListResponse": ".evaluation_set_item",
    "EvaluationSetItemUpdateResponse": ".evaluation_set_item",
    "EvaluationSetListResponse": ".evaluation_set",
    "ExcelSheetRange": ".types",
    "Extend": ".client",
    "ExtendEnvironment": ".environment",
    "ExtendError": ".types",
    "ExtractChunkingOptions": ".types",
    "ExtractChunkingOptionsChunkSelectionStrategy": ".types",
    "ExtractChunkingOptionsChunkingStrategy": ".types",
    "ExtractMetrics": ".types",
    "ExtractMetricsFieldMetrics": ".types",
    "ExtractOptimizerOptions": ".types",
    "ExtractionAdvancedOptions": ".types",
    "ExtractionAdvancedOptionsArrayCitationStrategy": ".types",
    "ExtractionAdvancedOptionsExcelSheetSelectionStrategy": ".types",
    "ExtractionAdvancedOptionsReviewAgent": ".types",
    "ExtractionConfig": ".types",
    "ExtractionConfigBaseProcessor": ".types",
    "ExtractionField": ".types",
    "ExtractionFieldMetrics": ".types",
    "ExtractionFieldResult": ".types",
    "ExtractionFieldResultReference": ".types",
    "ExtractionFieldResultReferenceBoundingBoxesItem": ".types",
    "ExtractionFieldResultType": ".types",
    "ExtractionFieldType": ".types",
    "ExtractionOutput": ".types",
    "ExtractionOutputEdits": ".types",
    "FieldsArrayOutput": ".types",
    "FigureDetails": ".types",
    "FigureDetailsFigureType": ".types",
    "File": ".types",
    "FileContents": ".types",
    "FileContentsPagesItem": ".types",
    "FileContentsSheetsItem": ".types",
    "FileCredits": ".types",
    "FileDeleteResponse": ".file",
    "FileGetResponse": ".file",
    "FileListResponse": ".file",
    "FileMetadata": ".types",
    "FileMetadataParentSplit": ".types",
    "FileType": ".types",
    "FileUploadResponse": ".file",
    "Insight": ".types",
    "InsightType": ".types",
    "InternalServerError": ".errors",
    "JsonObject": ".types",
    "JsonOutput": ".types",
    "JsonOutputMetadataValue": ".types",
    "JsonOutputMetadataValueCitationsItem": ".types",
    "JsonOutputMetadataValueCitationsItemPolygonItem": ".types",
    "ListProcessorsProcessor": ".types",
    "ListProcessorsProcessorVersion": ".types",
    "ListProcessorsResponse": ".types",
    "MaxPageSize": ".types",
    "NextPageToken": ".types",
    "NotFoundError": ".errors",
    "OptimizerBatchProcessorRunResult": ".types",
    "OptimizerBatchProcessorRunResultProcessorConfig": ".types",
    "OptimizerBatchProcessorRunResultProcessorConfig_Classify": ".types",
    "OptimizerBatchProcessorRunResultProcessorConfig_Extract": ".types",
    "OptimizerRun": ".types",
    "OptimizerRunAgentType": ".types",
    "OptimizerRunMetrics": ".types",
    "OptimizerRunMetricsFieldsItem": ".types",
    "OptimizerRunStatus": ".types",
    "OutputMetadata": ".types",
    "OutputMetadataValue": ".types",
    "PageRanges": ".types",
    "PageRangesItem": ".types",
    "ParseAsyncRequestFile": ".types",
    "ParseConfig": ".types",
    "ParseConfigAdvancedOptions": ".types",
    "ParseConfigBlockOptions": ".types",
    "ParseConfigBlockOptionsFigures": ".types",
    "ParseConfigBlockOptionsTables": ".types",
    "ParseConfigBlockOptionsTablesTargetFormat": ".types",
    "ParseConfigBlockOptionsText": ".types",
    "ParseConfigChunkingStrategy": ".types",
    "ParseConfigChunkingStrategyOptions": ".types",
    "ParseConfigChunkingStrategyType": ".types",
    "ParseConfigTarget": ".types",
    "ParseError": ".types",
    "ParseErrorCode": ".types",
    "ParseRequestFile": ".types",
    "ParseRequestResponseType": ".types",
    "ParserRun": ".types",
    "ParserRunCredits": ".types",
    "ParserRunDeleteResponse": ".parser_run",
    "ParserRunGetRequestResponseType": ".parser_run",
    "ParserRunGetResponse": ".parser_run",
    "ParserRunGetResponseParserRun": ".parser_run",
    "ParserRunGetResponseParserRun_ParserRun": ".parser_run",
    "ParserRunGetResponseParserRun_ParserRunStatus": ".parser_run",
    "ParserRunMetrics": ".types",
    "ParserRunStatus": ".types",
    "ParserRunStatusEnum": ".types",
    "ParserRunStatusStatus": ".types",
    "PaymentRequiredError": ".errors",
    "Polygon": ".types",
    "Processor": ".types",
    "ProcessorCreateRequestConfig": ".processor",
    "ProcessorCreateRequestConfig_Classify": ".processor",
    "ProcessorCreateRequestConfig_Extract": ".processor",
    "ProcessorCreateRequestConfig_Splitter": ".processor",
    "ProcessorCreateResponse": ".processor",
    "ProcessorId": ".types",
    "ProcessorListRequestSortBy": ".processor",
    "ProcessorListRequestSortDir": ".processor",
    "ProcessorOutput": ".types",
    "ProcessorRun": ".types",
    "ProcessorRunCancelResponse": ".processor_run",
    "ProcessorRunConfig": ".types",
    "ProcessorRunConfig_Classify": ".types",
    "ProcessorRunConfig_Extract": ".types",
    "ProcessorRunConfig_Splitter": ".types",
    "ProcessorRunCreateRequestConfig": ".processor_run",
    "ProcessorRunCreateRequestConfig_Classify": ".processor_run",
    "ProcessorRunCreateRequestConfig_Extract": ".processor_run",
    "ProcessorRunCreateRequestConfig_Splitter": ".processor_run",
    "ProcessorRunCreateResponse": ".processor_run",
    "ProcessorRunDeleteResponse": ".processor_run",
    "ProcessorRunFileInput": ".types",
    "ProcessorRunGetResponse": ".processor_run",
    "ProcessorRunListRequestSource": ".processor_run",
    "ProcessorRunListResponse": ".processor_run",
    "ProcessorRunMergedProcessorsItem": ".types",
    "ProcessorRunSummary": ".types",
    "ProcessorRunSummaryType": ".types",
    "ProcessorRunType": ".types",
    "ProcessorStatus": ".types",
    "ProcessorType": ".types",
    "ProcessorUpdateRequestConfig": ".processor",
    "ProcessorUpdateRequestConfig_Classify": ".processor",
    "ProcessorUpdateRequestConfig_Extract": ".processor",
    "ProcessorUpdateRequestConfig_Splitter": ".processor",
    "ProcessorUpdateResponse": ".processor",
    "ProcessorVersion": ".types",
    "ProcessorVersionConfig": ".types",
    "ProcessorVersionConfig_Classify": ".types",
    "ProcessorVersionConfig_Extract": ".types",
    "ProcessorVersionConfig_Splitter": ".types",
    "ProcessorVersionCreateRequestConfig": ".processor_version",
    "ProcessorVersionCreateRequestConfig_Classify": ".processor_version",
    "ProcessorVersionCreateRequestConfig_Extract": ".processor_version",
    "ProcessorVersionCreateRequestConfig_Splitter": ".processor_version",
    "ProcessorVersionCreateRequestReleaseType": ".processor_version",
    "ProcessorVersionCreateResponse": ".processor_version",
    "ProcessorVersionGetResponse": ".processor_version",
    "ProcessorVersionListResponse": ".processor_version",
    "ProvidedClassifierOutput": ".types",
    "ProvidedExtractionFieldResult": ".types",
    "ProvidedExtractionFieldResultType": ".types",
    "ProvidedExtractionOutput": ".types",
    "ProvidedFieldsArrayOutput": ".types",
    "ProvidedJsonOutput": ".types",
    "ProvidedProcessorOutput": ".types",
    "ProvidedSplitterOutput": ".types",
    "ProvidedSplitterOutputSplitsItem": ".types",
    "SortByEnum": ".types",
    "SortDirEnum": ".types",
    "SplitterAdvancedOptions": ".types",
    "SplitterAdvancedOptionsSplitMethod": ".types",
    "SplitterConfig": ".types",
    "SplitterConfigBaseProcessor": ".types",
    "SplitterMetrics": ".types",
    "SplitterOutput": ".types",
    "SplitterOutputSplitsItem": ".types",
    "StepRun": ".types",
    "StepRunOutput": ".types",
    "StepRunOutputRulesItem": ".types",
    "StepRunOutputRulesItemFailureReason": ".types",
    "StepRunStatus": ".types",
    "StepRunStep": ".types",
    "StepRunStepType": ".types",
    "TableCellDetails": ".types",
    "TableDetails": ".types",
    "TooManyRequestsError": ".errors",
    "TooManyRequestsErrorBody": ".types",
    "UnauthorizedError": ".errors",
    "UnprocessableEntityError": ".errors",
    "WebhookEvent": ".types",
    "WebhookEventEventType": ".types",
    "WebhookEventPayload": ".types",
    "WebhookEventProcessor": ".types",
    "WebhookEventProcessorEventType": ".types",
    "WebhookEventProcessorRun": ".types",
    "WebhookEventProcessorRunEventType": ".types",
    "WebhookEventProcessorVersion": ".types",
    "WebhookEventWorkflow": ".types",
    "WebhookEventWorkflowEventType": ".types",
    "WebhookEventWorkflowRun": ".types",
    "WebhookEventWorkflowRunEventType": ".types",
    "Workflow": ".types",
    "WorkflowCreateResponse": ".workflow",
    "WorkflowRun": ".types",
    "WorkflowRunCancelResponse": ".workflow_run",
    "WorkflowRunCancelResponseWorkflowRun": ".workflow_run",
    "WorkflowRunCreateResponse": ".workflow_run",
    "WorkflowRunCredits": ".types",
    "WorkflowRunDeleteResponse": ".workflow_run",
    "WorkflowRunFileInput": ".types",
    "WorkflowRunFileInputOutputsItem": ".types",
    "WorkflowRunGetResponse": ".workflow_run",
    "WorkflowRunListResponse": ".workflow_run",
    "WorkflowRunOutputUpdateResponse": ".workflow_run_output",
    "WorkflowRunSummary": ".types",
    "WorkflowRunUpdateResponse": ".workflow_run",
    "WorkflowStatus": ".types",
    "__version__": ".version",
    "batch_processor_run": ".batch_processor_run",
    "batch_workflow_run": ".batch_workflow_run",
    "edit": ".edit",
    "evaluation_set": ".evaluation_set",
    "evaluation_set_item": ".evaluation_set_item",
    "file": ".file",
    "parser_run": ".parser_run",
    "processor": ".processor",
    "processor_run": ".processor_run",
    "processor_version": ".processor_version",
    "workflow": ".workflow",
    "workflow_run": ".workflow_run",
    "workflow_run_output": ".workflow_run_output",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ApiVersionEnum",
    "ArrayStrategy",
    "ArrayStrategyType",
    "AsyncExtend",
    "BadRequestError",
    "BadRequestErrorBody",
    "BadRequestErrorBodyCode",
    "BaseMetrics",
    "BatchProcessorRun",
    "BatchProcessorRunGetResponse",
    "BatchProcessorRunMetrics",
    "BatchProcessorRunOptions",
    "BatchProcessorRunSource",
    "BatchProcessorRunStatus",
    "BatchWorkflowRunCreateRequestInputsItem",
    "BatchWorkflowRunCreateResponse",
    "BatchWorkflowRunFileInput",
    "Block",
    "BlockBoundingBox",
    "BlockDetails",
    "BlockMetadata",
    "BlockMetadataPage",
    "BlockPolygonItem",
    "BlockType",
    "Chunk",
    "ChunkMetadata",
    "ChunkMetadataPageRange",
    "ChunkType",
    "Citation",
    "Classification",
    "ClassificationAdvancedOptions",
    "ClassificationAdvancedOptionsContext",
    "ClassificationConfig",
    "ClassificationConfigBaseProcessor",
    "ClassificationFieldMetrics",
    "ClassifierOutput",
    "ClassifyMetrics",
    "ClassifyOptimizerOptions",
    "DocumentProcessorRunCredits",
    "EditBoundingBox",
    "EditCreateAsyncRequestConfig",
    "EditCreateAsyncRequestConfigAdvancedOptions",
    "EditCreateAsyncRequestFile",
    "EditCreateRequestConfig",
    "EditCreateRequestConfigAdvancedOptions",
    "EditCreateRequestFile",
    "EditDeleteResponse",
    "EditError",
    "EditErrorCode",
    "EditGetResponse",
    "EditGetResponseEditRun",
    "EditGetResponseEditRun_EditRun",
    "EditGetResponseEditRun_EditRunStatus",
    "EditJsonSchema",
    "EditJsonSchemaExtendEditFieldType",
    "EditObjectJsonSchema",
    "EditRootJsonSchema",
    "EditRun",
    "EditRunConfig",
    "EditRunConfigAdvancedOptions",
    "EditRunEditedFile",
    "EditRunMetrics",
    "EditRunStatus",
    "EditRunStatusStatus",
    "EditRunUsage",
    "EditTextOptions",
    "EmptyBlockDetails",
    "Enum",
    "EnumOption",
    "Error",
    "EvaluationSet",
    "EvaluationSetCreateResponse",
    "EvaluationSetGetResponse",
    "EvaluationSetItem",
    "EvaluationSetItemCreateBatchRequestItemsItem",
    "EvaluationSetItemCreateBatchResponse",
    "EvaluationSetItemCreateResponse",
    "EvaluationSetItemDeleteResponse",
    "EvaluationSetItemListResponse",
    "EvaluationSetItemUpdateResponse",
    "EvaluationSetListResponse",
    "ExcelSheetRange",
    "Extend",
    "ExtendEnvironment",
    "ExtendError",
    "ExtractChunkingOptions",
    "ExtractChunkingOptionsChunkSelectionStrategy",
    "ExtractChunkingOptionsChunkingStrategy",
    "ExtractMetrics",
    "ExtractMetricsFieldMetrics",
    "ExtractOptimizerOptions",
    "ExtractionAdvancedOptions",
    "ExtractionAdvancedOptionsArrayCitationStrategy",
    "ExtractionAdvancedOptionsExcelSheetSelectionStrategy",
    "ExtractionAdvancedOptionsReviewAgent",
    "ExtractionConfig",
    "ExtractionConfigBaseProcessor",
    "ExtractionField",
    "ExtractionFieldMetrics",
    "ExtractionFieldResult",
    "ExtractionFieldResultReference",
    "ExtractionFieldResultReferenceBoundingBoxesItem",
    "ExtractionFieldResultType",
    "ExtractionFieldType",
    "ExtractionOutput",
    "ExtractionOutputEdits",
    "FieldsArrayOutput",
    "FigureDetails",
    "FigureDetailsFigureType",
    "File",
    "FileContents",
    "FileContentsPagesItem",
    "FileContentsSheetsItem",
    "FileCredits",
    "FileDeleteResponse",
    "FileGetResponse",
    "FileListResponse",
    "FileMetadata",
    "FileMetadataParentSplit",
    "FileType",
    "FileUploadResponse",
    "Insight",
    "InsightType",
    "InternalServerError",
    "JsonObject",
    "JsonOutput",
    "JsonOutputMetadataValue",
    "JsonOutputMetadataValueCitationsItem",
    "JsonOutputMetadataValueCitationsItemPolygonItem",
    "ListProcessorsProcessor",
    "ListProcessorsProcessorVersion",
    "ListProcessorsResponse",
    "MaxPageSize",
    "NextPageToken",
    "NotFoundError",
    "OptimizerBatchProcessorRunResult",
    "OptimizerBatchProcessorRunResultProcessorConfig",
    "OptimizerBatchProcessorRunResultProcessorConfig_Classify",
    "OptimizerBatchProcessorRunResultProcessorConfig_Extract",
    "OptimizerRun",
    "OptimizerRunAgentType",
    "OptimizerRunMetrics",
    "OptimizerRunMetricsFieldsItem",
    "OptimizerRunStatus",
    "OutputMetadata",
    "OutputMetadataValue",
    "PageRanges",
    "PageRangesItem",
    "ParseAsyncRequestFile",
    "ParseConfig",
    "ParseConfigAdvancedOptions",
    "ParseConfigBlockOptions",
    "ParseConfigBlockOptionsFigures",
    "ParseConfigBlockOptionsTables",
    "ParseConfigBlockOptionsTablesTargetFormat",
    "ParseConfigBlockOptionsText",
    "ParseConfigChunkingStrategy",
    "ParseConfigChunkingStrategyOptions",
    "ParseConfigChunkingStrategyType",
    "ParseConfigTarget",
    "ParseError",
    "ParseErrorCode",
    "ParseRequestFile",
    "ParseRequestResponseType",
    "ParserRun",
    "ParserRunCredits",
    "ParserRunDeleteResponse",
    "ParserRunGetRequestResponseType",
    "ParserRunGetResponse",
    "ParserRunGetResponseParserRun",
    "ParserRunGetResponseParserRun_ParserRun",
    "ParserRunGetResponseParserRun_ParserRunStatus",
    "ParserRunMetrics",
    "ParserRunStatus",
    "ParserRunStatusEnum",
    "ParserRunStatusStatus",
    "PaymentRequiredError",
    "Polygon",
    "Processor",
    "ProcessorCreateRequestConfig",
    "ProcessorCreateRequestConfig_Classify",
    "ProcessorCreateRequestConfig_Extract",
    "ProcessorCreateRequestConfig_Splitter",
    "ProcessorCreateResponse",
    "ProcessorId",
    "ProcessorListRequestSortBy",
    "ProcessorListRequestSortDir",
    "ProcessorOutput",
    "ProcessorRun",
    "ProcessorRunCancelResponse",
    "ProcessorRunConfig",
    "ProcessorRunConfig_Classify",
    "ProcessorRunConfig_Extract",
    "ProcessorRunConfig_Splitter",
    "ProcessorRunCreateRequestConfig",
    "ProcessorRunCreateRequestConfig_Classify",
    "ProcessorRunCreateRequestConfig_Extract",
    "ProcessorRunCreateRequestConfig_Splitter",
    "ProcessorRunCreateResponse",
    "ProcessorRunDeleteResponse",
    "ProcessorRunFileInput",
    "ProcessorRunGetResponse",
    "ProcessorRunListRequestSource",
    "ProcessorRunListResponse",
    "ProcessorRunMergedProcessorsItem",
    "ProcessorRunSummary",
    "ProcessorRunSummaryType",
    "ProcessorRunType",
    "ProcessorStatus",
    "ProcessorType",
    "ProcessorUpdateRequestConfig",
    "ProcessorUpdateRequestConfig_Classify",
    "ProcessorUpdateRequestConfig_Extract",
    "ProcessorUpdateRequestConfig_Splitter",
    "ProcessorUpdateResponse",
    "ProcessorVersion",
    "ProcessorVersionConfig",
    "ProcessorVersionConfig_Classify",
    "ProcessorVersionConfig_Extract",
    "ProcessorVersionConfig_Splitter",
    "ProcessorVersionCreateRequestConfig",
    "ProcessorVersionCreateRequestConfig_Classify",
    "ProcessorVersionCreateRequestConfig_Extract",
    "ProcessorVersionCreateRequestConfig_Splitter",
    "ProcessorVersionCreateRequestReleaseType",
    "ProcessorVersionCreateResponse",
    "ProcessorVersionGetResponse",
    "ProcessorVersionListResponse",
    "ProvidedClassifierOutput",
    "ProvidedExtractionFieldResult",
    "ProvidedExtractionFieldResultType",
    "ProvidedExtractionOutput",
    "ProvidedFieldsArrayOutput",
    "ProvidedJsonOutput",
    "ProvidedProcessorOutput",
    "ProvidedSplitterOutput",
    "ProvidedSplitterOutputSplitsItem",
    "SortByEnum",
    "SortDirEnum",
    "SplitterAdvancedOptions",
    "SplitterAdvancedOptionsSplitMethod",
    "SplitterConfig",
    "SplitterConfigBaseProcessor",
    "SplitterMetrics",
    "SplitterOutput",
    "SplitterOutputSplitsItem",
    "StepRun",
    "StepRunOutput",
    "StepRunOutputRulesItem",
    "StepRunOutputRulesItemFailureReason",
    "StepRunStatus",
    "StepRunStep",
    "StepRunStepType",
    "TableCellDetails",
    "TableDetails",
    "TooManyRequestsError",
    "TooManyRequestsErrorBody",
    "UnauthorizedError",
    "UnprocessableEntityError",
    "WebhookEvent",
    "WebhookEventEventType",
    "WebhookEventPayload",
    "WebhookEventProcessor",
    "WebhookEventProcessorEventType",
    "WebhookEventProcessorRun",
    "WebhookEventProcessorRunEventType",
    "WebhookEventProcessorVersion",
    "WebhookEventWorkflow",
    "WebhookEventWorkflowEventType",
    "WebhookEventWorkflowRun",
    "WebhookEventWorkflowRunEventType",
    "Workflow",
    "WorkflowCreateResponse",
    "WorkflowRun",
    "WorkflowRunCancelResponse",
    "WorkflowRunCancelResponseWorkflowRun",
    "WorkflowRunCreateResponse",
    "WorkflowRunCredits",
    "WorkflowRunDeleteResponse",
    "WorkflowRunFileInput",
    "WorkflowRunFileInputOutputsItem",
    "WorkflowRunGetResponse",
    "WorkflowRunListResponse",
    "WorkflowRunOutputUpdateResponse",
    "WorkflowRunSummary",
    "WorkflowRunUpdateResponse",
    "WorkflowStatus",
    "__version__",
    "batch_processor_run",
    "batch_workflow_run",
    "edit",
    "evaluation_set",
    "evaluation_set_item",
    "file",
    "parser_run",
    "processor",
    "processor_run",
    "processor_version",
    "workflow",
    "workflow_run",
    "workflow_run_output",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .edit_run_status_status import EditRunStatusStatus


class EditRunStatus(UncheckedBaseModel):
    """
    Minimal edit run status object without edit results.
    """

    object: typing.Literal["edit_run_status"] = pydantic.Field(default="edit_run_status")
    """
    The type of object. Will always be `"edit_run_status"`.
    """

    id: str = pydantic.Field()
    """
    A unique identifier for the edit run. Will always start with `"edit_run_"`
    
    Example: `"edit_run_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    status: EditRunStatusStatus = pydantic.Field()
    """
    The status of the edit run.
    """

    failure_reason: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureReason")] = (
        pydantic.Field(alias="failureReason", default=None)
    )
    """
    The reason for failure if status is "FAILED".
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.processor_run import ProcessorRun


class ProcessorRunGetResponse(UncheckedBaseModel):
    success: bool
    processor_run: typing_extensions.Annotated[ProcessorRun, FieldMetadata(alias="processorRun")] = pydantic.Field(
        alias="processorRun"
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(ProcessorRunGetResponse)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel, UnionMetadata
from ...types.edit_run_config import EditRunConfig
from ...types.edit_run_edited_file import EditRunEditedFile
from ...types.edit_run_metrics import EditRunMetrics
from ...types.edit_run_status import EditRunStatus
from ...types.edit_run_status_status import EditRunStatusStatus
from ...types.edit_run_usage import EditRunUsage


class EditGetResponseEditRun_EditRunStatus(UncheckedBaseModel):
    object: typing.Literal["edit_run_status"] = "edit_run_status"
    id: str
    status: EditRunStatusStatus
    failure_reason: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureReason")] = (
        pydantic.Field(alias="failureReason", default=None)
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EditGetResponseEditRun_EditRun(UncheckedBaseModel):
    object: typing.Literal["edit_run"] = "edit_run"
    id: str
    file_id: typing_extensions.Annotated[str, FieldMetadata(alias="fileId")] = pydantic.Field(alias="fileId")
    edited_file: typing_extensions.Annotated[typing.Optional[EditRunEditedFile], FieldMetadata(alias="editedFile")] = (
        pydantic.Field(alias="editedFile", default=None)
    )
    status: EditRunStatus
    failure_reason: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureReason")] = (
        pydantic.Field(alias="failureReason", default=None)
    )
    config: EditRunConfig
    output: typing.Optional[typing.Dict[str, typing.Any]] = None
    metrics: EditRunMetrics
    usage: typing.Optional[EditRunUsage] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


EditGetResponseEditRun = typing_extensions.Annotated[
    typing.Union[EditGetResponseEditRun_EditRunStatus, EditGetResponseEditRun_EditRun],
    UnionMetadata(discriminant="object"),
]
update_forward_refs(EditGetResponseEditRun_EditRun)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class ClassifyOptimizerOptions(UncheckedBaseModel):
    agent_type: typing_extensions.Annotated[typing.Literal["CLASSIFY_OPTIMIZER"], FieldMetadata(alias="agentType")] = (
        pydantic.Field(alias="agentType", default="CLASSIFY_OPTIMIZER")
    )
    """
    Type of optimizer agent
    """

    accuracy_threshold: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="accuracyThreshold")
    ] = pydantic.Field(alias="accuracyThreshold", default=None)
    """
    Target accuracy threshold (0-1)
    """

    max_batch_runs: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="maxBatchRuns")] = (
        pydantic.Field(alias="maxBatchRuns", default=None)
    )
    """
    Maximum number of batch iterations
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .edit_bounding_box import EditBoundingBox
from .edit_json_schema_extend_edit_field_type import EditJsonSchemaExtendEditFieldType
from .edit_text_options import EditTextOptions


class EditJsonSchema(UncheckedBaseModel):
    """
    Schema definition for a field to edit in a PDF. This is a union type that supports:
    * `EditStringJSONSchema` - type: ["string", "null"], field_type: "text" | "signature"
    * `EditNumberJSONSchema` - type: ["number", "null"], field_type: "text"
    * `EditIntegerJSONSchema` - type: ["integer", "null"], field_type: "text"
    * `EditBooleanJSONSchema` - type: ["boolean", "null"], field_type: "checkbox" | "radio"
    * `EditArrayJSONSchema` - type: "array", field_type: "text" | "table"
    * `EditEnumJSONSchema` - has enum property (no type field), field_type: "radio" | "optionList" | "dropdown"
    * `EditObjectJSONSchema` - type: "object", field_type: "signature"

    All variants share common `extend_edit:*` properties for positioning and styling.
    """

    type: typing.Optional[typing.Any] = pydantic.Field(default=None)
    """
    The JSON schema type of the field. Can be:
    * A string: "array" or "object"
    * A nullable tuple array: ["string", "null"], ["number", "null"], ["integer", "null"], ["boolean", "null"]
    * Omitted for enum fields (use enum property instead)
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Description of the field
    """

    extend_edit_field_type: typing_extensions.Annotated[
        typing.Optional[EditJsonSchemaExtendEditFieldType], FieldMetadata(alias="extend_edit:field_type")
    ] = pydantic.Field(alias="extend_edit:field_type", default=None)
    """
    The PDF field type to edit. Allowed values depend on the schema type:
    * `["string", "null"]` → `text`, `signature`
    * `["number", "null"]` → `text`
    * `["integer", "null"]` → `text`
    * `["boolean", "null"]` → `checkbox`, `radio`
    * `"array"` → `text`, `table`
    * `"object"` → `signature`
    * enum fields (no type) → `radio`, `optionList`, `dropdown`
    """

    extend_edit_bbox: typing_extensions.Annotated[
        typing.Optional[EditBoundingBox], FieldMetadata(alias="extend_edit:bbox")
    ] = pydantic.Field(alias="extend_edit:bbox", default=None)
    extend_edit_page_index: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="extend_edit:page_index")
    ] = pydantic.Field(alias="extend_edit:page_index", default=None)
    """
    Zero-based page index where the field should be placed
    """

    extend_edit_text_edit_options: typing_extensions.Annotated[
        typing.Optional[EditTextOptions], FieldMetadata(alias="extend_edit:text_edit_options")
    ] = pydantic.Field(alias="extend_edit:text_edit_options", default=None)
    extend_edit_column_width: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="extend_edit:column_width")
    ] = pydantic.Field(alias="extend_edit:column_width", default=None)
    """
    Width of the column as a percentage (for table fields)
    """

    extend_edit_value: typing_extensions.Annotated[
        typing.Optional[typing.Any], FieldMetadata(alias="extend_edit:value")
    ] = pydantic.Field(alias="extend_edit:value", default=None)
    """
    The value to fill into this field. Can be any type. This will force the value at this field to be filled with this value. If a value is not provided, we will attempt to generate or infer one based on the instructions.
    """

    extend_edit_row_heights: typing_extensions.Annotated[
        typing.Optional[typing.List[float]], FieldMetadata(alias="extend_edit:row_heights")
    ] = pydantic.Field(alias="extend_edit:row_heights", default=None)
    """
    Array of row height percentages for array/table fields (e.g. [0.25, 0.50, 0.25])
    """

    items: typing.Optional["EditObjectJsonSchema"] = pydantic.Field(default=None)
    """
    Schema for array items (when type is "array"). Must be an EditObjectJSONSchema.
    """

    properties: typing.Optional[typing.Dict[str, "EditJsonSchema"]] = pydantic.Field(default=None)
    """
    Nested properties for object types. Each property follows the EditJSONSchema structure.
    """

    enum: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Allowed values for enum/dropdown/radio fields
    """

    max_items: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="maxItems")] = pydantic.Field(
        alias="maxItems", default=None
    )
    """
    Maximum number of rows for array/table fields
    """

    required: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of required property names (for object types)
    """

    additional_properties: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="additionalProperties")
    ] = pydantic.Field(alias="additionalProperties", default=None)
    """
    Whether additional properties are allowed (for object types)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .edit_object_json_schema import EditObjectJsonSchema  # noqa: E402, I001

update_forward_refs(EditJsonSchema, EditObjectJsonSchema=EditObjectJsonSchema)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .edit_error_code import EditErrorCode


class EditError(UncheckedBaseModel):
    code: typing.Optional[EditErrorCode] = None
    message: typing.Optional[str] = None
    request_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="requestId")] = pydantic.Field(
        alias="requestId", default=None
    )
    retryable: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import httpx
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .core.request_options import RequestOptions
from .environment import ExtendEnvironment
from .raw_client import AsyncRawExtend, RawExtend
from .types.parse_async_request_file import ParseAsyncRequestFile
from .types.parse_config import ParseConfig
from .types.parse_request_file import ParseRequestFile
from .types.parse_request_response_type import ParseRequestResponseType
from .types.parser_run import ParserRun
from .types.parser_run_status import ParserRunStatus

if typing.TYPE_CHECKING:
    from .batch_processor_run.client import AsyncBatchProcessorRunClient, BatchProcessorRunClient
    from .batch_workflow_run.client import AsyncBatchWorkflowRunClient, BatchWorkflowRunClient
    from .edit.client import AsyncEditClient, EditClient
    from .evaluation_set.client import AsyncEvaluationSetClient, EvaluationSetClient
    from .evaluation_set_item.client import AsyncEvaluationSetItemClient, EvaluationSetItemClient
    from .file.client import AsyncFileClient, FileClient
    from .parser_run.client import AsyncParserRunClient, ParserRunClient
    from .processor.client import AsyncProcessorClient, ProcessorClient
    from .processor_run.client import AsyncProcessorRunClient, ProcessorRunClient
    from .processor_version.client import AsyncProcessorVersionClient, ProcessorVersionClient
    from .workflow.client import AsyncWorkflowClient, WorkflowClient
    from .workflow_run.client import AsyncWorkflowRunClient, WorkflowRunClient
    from .workflow_run_output.client import AsyncWorkflowRunOutputClient, WorkflowRunOutputClient
# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class Extend:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ExtendEnvironment
        The environment to use for requests from the client. from .environment import ExtendEnvironment



        Defaults to ExtendEnvironment.PRODUCTION



    token : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 300 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    extend_api_version : typing.Optional[str]
    Examples
    --------
    from extend_ai import Extend

    client = Extend(
        token="YOUR_TOKEN",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ExtendEnvironment = ExtendEnvironment.PRODUCTION,
        token: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = None,
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
        extend_api_version: typing.Optional[str] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 300 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
            extend_api_version=extend_api_version,
        )
        self._raw_client = RawExtend(client_wrapper=self._client_wrapper)
        self._workflow_run: typing.Optional[WorkflowRunClient] = None
        self._batch_workflow_run: typing.Optional[BatchWorkflowRunClient] = None
        self._processor_run: typing.Optional[ProcessorRunClient] = None
        self._processor: typing.Optional[ProcessorClient] = None
        self._processor_version: typing.Optional[ProcessorVersionClient] = None
        self._parser_run: typing.Optional[ParserRunClient] = None
        self._edit: typing.Optional[EditClient] = None
        self._file: typing.Optional[FileClient] = None
        self._evaluation_set: typing.Optional[EvaluationSetClient] = None
        self._evaluation_set_item: typing.Optional[EvaluationSetItemClient] = None
        self._workflow_run_output: typing.Optional[WorkflowRunOutputClient] = None
        self._batch_processor_run: typing.Optional[BatchProcessorRunClient] = None
        self._workflow: typing.Optional[WorkflowClient] = None

    @property
    def with_raw_response(self) -> RawExtend:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawExtend
        """
        return self._raw_client

    def parse(
        self,
        *,
        file: ParseRequestFile,
        response_type: typing.Optional[ParseRequestResponseType] = None,
        config: typing.Optional[ParseConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ParserRun:
        """
        Parse files to get cleaned, chunked target content (e.g. markdown).

        The Parse endpoint allows you to convert documents into structured, machine-readable formats with fine-grained control over the parsing process. This endpoint is ideal for extracting cleaned document content to be used as context for downstream processing, e.g. RAG pipelines, custom ingestion pipelines, embeddings classification, etc.

        For more details, see the [Parse File guide](/product/parsing/parse).

        Parameters
        ----------
        file : ParseRequestFile
            A file object containing either a URL or a fileId.

        response_type : typing.Optional[ParseRequestResponseType]
            Controls the format of the response chunks. Defaults to `json` if not specified.
            * `json` - Returns parsed outputs in the response body
            * `url` - Return a presigned URL to the parsed content in the response body

        config : typing.Optional[ParseConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParserRun
            Successfully parsed file

        Examples
        --------
        from extend_ai import Extend, ParseRequestFile

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.parse(
            response_type="json",
            file=ParseRequestFile(),
        )
        """
        _response = self._raw_client.parse(
            file=file, response_type=response_type, config=config, request_options=request_options
        )
        return _response.data

    def parse_async(
        self,
        *,
        file: ParseAsyncRequestFile,
        config: typing.Optional[ParseConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ParserRunStatus:
        """
        Parse files **asynchronously** to get cleaned, chunked target content (e.g. markdown).

        The Parse Async endpoint allows you to convert documents into structured, machine-readable formats with fine-grained control over the parsing process. This endpoint is ideal for extracting cleaned document content to be used as context for downstream processing, e.g. RAG pipelines, custom ingestion pipelines, embeddings classification, etc.

        Parse files asynchronously and get a parser run ID that can be used to check status and retrieve results with the [Get Parser Run](https://docs.extend.ai/2025-04-21/developers/api-reference/parse-endpoints/get-parser-run) endpoint.

        This is useful for:
        * Large files that may take longer to process
        * Avoiding timeout issues with synchronous parsing.

        For more details, see the [Parse File guide](/product/parsing/parse).

        Parameters
        ----------
        file : ParseAsyncRequestFile
            A file object containing either a URL or a fileId.

        config : typing.Optional[ParseConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParserRunStatus
            Successfully initiated parser run

        Examples
        --------
        from extend_ai import Extend, ParseAsyncRequestFile

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.parse_async(
            file=ParseAsyncRequestFile(),
        )
        """
        _response = self._raw_client.parse_async(file=file, config=config, request_options=request_options)
        return _response.data

    @property
    def workflow_run(self):
        if self._workflow_run is None:
            from .workflow_run.client import WorkflowRunClient  # noqa: E402

            self._workflow_run = WorkflowRunClient(client_wrapper=self._client_wrapper)
        return self._workflow_run

    @property
    def batch_workflow_run(self):
        if self._batch_workflow_run is None:
            from .batch_workflow_run.client import BatchWorkflowRunClient  # noqa: E402

            self._batch_workflow_run = BatchWorkflowRunClient(client_wrapper=self._client_wrapper)
        return self._batch_workflow_run

    @property
    def processor_run(self):
        if self._processor_run is None:
            from .processor_run.client import ProcessorRunClient  # noqa: E402

            self._processor_run = ProcessorRunClient(client_wrapper=self._client_wrapper)
        return self._processor_run

    @property
    def processor(self):
        if self._processor is None:
            from .processor.client import ProcessorClient  # noqa: E402

            self._processor = ProcessorClient(client_wrapper=self._client_wrapper)
        return self._processor

    @property
    def processor_version(self):
        if self._processor_version is None:
            from .processor_version.client import ProcessorVersionClient  # noqa: E402

            self._processor_version = ProcessorVersionClient(client_wrapper=self._client_wrapper)
        return self._processor_version

    @property
    def parser_run(self):
        if self._parser_run is None:
            from .parser_run.client import ParserRunClient  # noqa: E402

            self._parser_run = ParserRunClient(client_wrapper=self._client_wrapper)
        return self._parser_run

    @property
    def edit(self):
        if self._edit is None:
            from .edit.client import EditClient  # noqa: E402

            self._edit = EditClient(client_wrapper=self._client_wrapper)
        return self._edit

    @property
    def file(self):
        if self._file is None:
            from .file.client import FileClient  # noqa: E402

            self._file = FileClient(client_wrapper=self._client_wrapper)
        return self._file

    @property
    def evaluation_set(self):
        if self._evaluation_set is None:
            from .evaluation_set.client import EvaluationSetClient  # noqa: E402

            self._evaluation_set = EvaluationSetClient(client_wrapper=self._client_wrapper)
        return self._evaluation_set

    @property
    def evaluation_set_item(self):
        if self._evaluation_set_item is None:
            from .evaluation_set_item.client import EvaluationSetItemClient  # noqa: E402

            self._evaluation_set_item = EvaluationSetItemClient(client_wrapper=self._client_wrapper)
        return self._evaluation_set_item

    @property
    def workflow_run_output(self):
        if self._workflow_run_output is None:
            from .workflow_run_output.client import WorkflowRunOutputClient  # noqa: E402

            self._workflow_run_output = WorkflowRunOutputClient(client_wrapper=self._client_wrapper)
        return self._workflow_run_output

    @property
    def batch_processor_run(self):
        if self._batch_processor_run is None:
            from .batch_processor_run.client import BatchProcessorRunClient  # noqa: E402

            self._batch_processor_run = BatchProcessorRunClient(client_wrapper=self._client_wrapper)
        return self._batch_processor_run

    @property
    def workflow(self):
        if self._workflow is None:
            from .workflow.client import WorkflowClient  # noqa: E402

            self._workflow = WorkflowClient(client_wrapper=self._client_wrapper)
        return self._workflow


class AsyncExtend:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ExtendEnvironment
        The environment to use for requests from the client. from .environment import ExtendEnvironment



        Defaults to ExtendEnvironment.PRODUCTION



    token : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 300 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    extend_api_version : typing.Optional[str]
    Examples
    --------
    from extend_ai import AsyncExtend

    client = AsyncExtend(
        token="YOUR_TOKEN",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ExtendEnvironment = ExtendEnvironment.PRODUCTION,
        token: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = None,
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
        extend_api_version: typing.Optional[str] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 300 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
            extend_api_version=extend_api_version,
        )
        self._raw_client = AsyncRawExtend(client_wrapper=self._client_wrapper)
        self._workflow_run: typing.Optional[AsyncWorkflowRunClient] = None
        self._batch_workflow_run: typing.Optional[AsyncBatchWorkflowRunClient] = None
        self._processor_run: typing.Optional[AsyncProcessorRunClient] = None
        self._processor: typing.Optional[AsyncProcessorClient] = None
        self._processor_version: typing.Optional[AsyncProcessorVersionClient] = None
        self._parser_run: typing.Optional[AsyncParserRunClient] = None
        self._edit: typing.Optional[AsyncEditClient] = None
        self._file: typing.Optional[AsyncFileClient] = None
        self._evaluation_set: typing.Optional[AsyncEvaluationSetClient] = None
        self._evaluation_set_item: typing.Optional[AsyncEvaluationSetItemClient] = None
        self._workflow_run_output: typing.Optional[AsyncWorkflowRunOutputClient] = None
        self._batch_processor_run: typing.Optional[AsyncBatchProcessorRunClient] = None
        self._workflow: typing.Optional[AsyncWorkflowClient] = None

    @property
    def with_raw_response(self) -> AsyncRawExtend:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawExtend
        """
        return self._raw_client

    async def parse(
        self,
        *,
        file: ParseRequestFile,
        response_type: typing.Optional[ParseRequestResponseType] = None,
        config: typing.Optional[ParseConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ParserRun:
        """
        Parse files to get cleaned, chunked target content (e.g. markdown).

        The Parse endpoint allows you to convert documents into structured, machine-readable formats with fine-grained control over the parsing process. This endpoint is ideal for extracting cleaned document content to be used as context for downstream processing, e.g. RAG pipelines, custom ingestion pipelines, embeddings classification, etc.

        For more details, see the [Parse File guide](/product/parsing/parse).

        Parameters
        ----------
        file : ParseRequestFile
            A file object containing either a URL or a fileId.

        response_type : typing.Optional[ParseRequestResponseType]
            Controls the format of the response chunks. Defaults to `json` if not specified.
            * `json` - Returns parsed outputs in the response body
            * `url` - Return a presigned URL to the parsed content in the response body

        config : typing.Optional[ParseConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParserRun
            Successfully parsed file

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend, ParseRequestFile

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.parse(
                response_type="json",
                file=ParseRequestFile(),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.parse(
            file=file, response_type=response_type, config=config, request_options=request_options
        )
        return _response.data

    async def parse_async(
        self,
        *,
        file: ParseAsyncRequestFile,
        config: typing.Optional[ParseConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ParserRunStatus:
        """
        Parse files **asynchronously** to get cleaned, chunked target content (e.g. markdown).

        The Parse Async endpoint allows you to convert documents into structured, machine-readable formats with fine-grained control over the parsing process. This endpoint is ideal for extracting cleaned document content to be used as context for downstream processing, e.g. RAG pipelines, custom ingestion pipelines, embeddings classification, etc.

        Parse files asynchronously and get a parser run ID that can be used to check status and retrieve results with the [Get Parser Run](https://docs.extend.ai/2025-04-21/developers/api-reference/parse-endpoints/get-parser-run) endpoint.

        This is useful for:
        * Large files that may take longer to process
        * Avoiding timeout issues with synchronous parsing.

        For more details, see the [Parse File guide](/product/parsing/parse).

        Parameters
        ----------
        file : ParseAsyncRequestFile
            A file object containing either a URL or a fileId.

        config : typing.Optional[ParseConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParserRunStatus
            Successfully initiated parser run

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend, ParseAsyncRequestFile

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.parse_async(
                file=ParseAsyncRequestFile(),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.parse_async(file=file, config=config, request_options=request_options)
        return _response.data

    @property
    def workflow_run(self):
        if self._workflow_run is None:
            from .workflow_run.client import AsyncWorkflowRunClient  # noqa: E402

            self._workflow_run = AsyncWorkflowRunClient(client_wrapper=self._client_wrapper)
        return self._workflow_run

    @property
    def batch_workflow_run(self):
        if self._batch_workflow_run is None:
            from .batch_workflow_run.client import AsyncBatchWorkflowRunClient  # noqa: E402

            self._batch_workflow_run = AsyncBatchWorkflowRunClient(client_wrapper=self._client_wrapper)
        return self._batch_workflow_run

    @property
    def processor_run(self):
        if self._processor_run is None:
            from .processor_run.client import AsyncProcessorRunClient  # noqa: E402

            self._processor_run = AsyncProcessorRunClient(client_wrapper=self._client_wrapper)
        return self._processor_run

    @property
    def processor(self):
        if self._processor is None:
            from .processor.client import AsyncProcessorClient  # noqa: E402

            self._processor = AsyncProcessorClient(client_wrapper=self._client_wrapper)
        return self._processor

    @property
    def processor_version(self):
        if self._processor_version is None:
            from .processor_version.client import AsyncProcessorVersionClient  # noqa: E402

            self._processor_version = AsyncProcessorVersionClient(client_wrapper=self._client_wrapper)
        return self._processor_version

    @property
    def parser_run(self):
        if self._parser_run is None:
            from .parser_run.client import AsyncParserRunClient  # noqa: E402

            self._parser_run = AsyncParserRunClient(client_wrapper=self._client_wrapper)
        return self._parser_run

    @property
    def edit(self):
        if self._edit is None:
            from .edit.client import AsyncEditClient  # noqa: E402

            self._edit = AsyncEditClient(client_wrapper=self._client_wrapper)
        return self._edit

    @property
    def file(self):
        if self._file is None:
            from .file.client import AsyncFileClient  # noqa: E402

            self._file = AsyncFileClient(client_wrapper=self._client_wrapper)
        return self._file

    @property
    def evaluation_set(self):
        if self._evaluation_set is None:
            from .evaluation_set.client import AsyncEvaluationSetClient  # noqa: E402

            self._evaluation_set = AsyncEvaluationSetClient(client_wrapper=self._client_wrapper)
        return self._evaluation_set

    @property
    def evaluation_set_item(self):
        if self._evaluation_set_item is None:
            from .evaluation_set_item.client import AsyncEvaluationSetItemClient  # noqa: E402

            self._evaluation_set_item = AsyncEvaluationSetItemClient(client_wrapper=self._client_wrapper)
        return self._evaluation_set_item

    @property
    def workflow_run_output(self):
        if self._workflow_run_output is None:
            from .workflow_run_output.client import AsyncWorkflowRunOutputClient  # noqa: E402

            self._workflow_run_output = AsyncWorkflowRunOutputClient(client_wrapper=self._client_wrapper)
        return self._workflow_run_output

    @property
    def batch_processor_run(self):
        if self._batch_processor_run is None:
            from .batch_processor_run.client import AsyncBatchProcessorRunClient  # noqa: E402

            self._batch_processor_run = AsyncBatchProcessorRunClient(client_wrapper=self._client_wrapper)
        return self._batch_processor_run

    @property
    def workflow(self):
        if self._workflow is None:
            from .workflow.client import AsyncWorkflowClient  # noqa: E402

            self._workflow = AsyncWorkflowClient(client_wrapper=self._client_wrapper)
        return self._workflow


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: ExtendEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

import typing

ExtractionAdvancedOptionsExcelSheetSelectionStrategy = typing.Union[
    typing.Literal["intelligent", "all", "first", "last"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .edit_create_async_request_config import EditCreateAsyncRequestConfig
    from .edit_create_async_request_config_advanced_options import EditCreateAsyncRequestConfigAdvancedOptions
    from .edit_create_async_request_file import EditCreateAsyncRequestFile
    from .edit_create_request_config import EditCreateRequestConfig
    from .edit_create_request_config_advanced_options import EditCreateRequestConfigAdvancedOptions
    from .edit_create_request_file import EditCreateRequestFile
    from .edit_delete_response import EditDeleteResponse
    from .edit_get_response import EditGetResponse
    from .edit_get_response_edit_run import (
        EditGetResponseEditRun,
        EditGetResponseEditRun_EditRun,
        EditGetResponseEditRun_EditRunStatus,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "EditCreateAsyncRequestConfig": ".edit_create_async_request_config",
    "EditCreateAsyncRequestConfigAdvancedOptions": ".edit_create_async_request_config_advanced_options",
    "EditCreateAsyncRequestFile": ".edit_create_async_request_file",
    "EditCreateRequestConfig": ".edit_create_request_config",
    "EditCreateRequestConfigAdvancedOptions": ".edit_create_request_config_advanced_options",
    "EditCreateRequestFile": ".edit_create_request_file",
    "EditDeleteResponse": ".edit_delete_response",
    "EditGetResponse": ".edit_get_response",
    "EditGetResponseEditRun": ".edit_get_response_edit_run",
    "EditGetResponseEditRun_EditRun": ".edit_get_response_edit_run",
    "EditGetResponseEditRun_EditRunStatus": ".edit_get_response_edit_run",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "EditCreateAsyncRequestConfig",
    "EditCreateAsyncRequestConfigAdvancedOptions",
    "EditCreateAsyncRequestFile",
    "EditCreateRequestConfig",
    "EditCreateRequestConfigAdvancedOptions",
    "EditCreateRequestFile",
    "EditDeleteResponse",
    "EditGetResponse",
    "EditGetResponseEditRun",
    "EditGetResponseEditRun_EditRun",
    "EditGetResponseEditRun_EditRunStatus",
]



# This file was auto-generated by Fern from our API Definition.

import typing

EditJsonSchemaExtendEditFieldType = typing.Union[
    typing.Literal["text", "checkbox", "radio", "dropdown", "optionList", "signature", "table", "unknown"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

ProcessorRunListRequestSource = typing.Union[
    typing.Literal[
        "ADMIN", "BATCH_PROCESSOR_RUN", "PLAYGROUND", "WORKFLOW_CONFIGURATION", "WORKFLOW_RUN", "STUDIO", "API"
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .optimizer_run_metrics_fields_item import OptimizerRunMetricsFieldsItem


class OptimizerRunMetrics(UncheckedBaseModel):
    overall_accuracy: typing_extensions.Annotated[float, FieldMetadata(alias="overallAccuracy")] = pydantic.Field(
        alias="overallAccuracy"
    )
    """
    Overall accuracy across all fields/classifications
    """

    fields: typing.List[OptimizerRunMetricsFieldsItem] = pydantic.Field()
    """
    Per-field or per-classification accuracy metrics.
    For `EXTRACT_OPTIMIZER`: each entry represents a field in the schema.
    For `CLASSIFY_OPTIMIZER`: each entry represents a classification category.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class EditRunMetrics(UncheckedBaseModel):
    """
    Metrics about the editing process.
    """

    processing_time_ms: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="processingTimeMs")] = (
        pydantic.Field(alias="processingTimeMs", default=None)
    )
    """
    Total processing time in milliseconds
    """

    field_count: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="fieldCount")] = pydantic.Field(
        alias="fieldCount", default=None
    )
    """
    The number of fields detected in the document.
    """

    page_count: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="pageCount")] = pydantic.Field(
        alias="pageCount", default=None
    )
    """
    The number of pages in the document.
    """

    field_filling_time_ms: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="fieldFillingTimeMs")
    ] = pydantic.Field(alias="fieldFillingTimeMs", default=None)
    """
    The time taken to fill the fields in the document.
    """

    field_detection_time_ms: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="fieldDetectionTimeMs")
    ] = pydantic.Field(alias="fieldDetectionTimeMs", default=None)
    """
    The time taken to detect the fields in the document.
    """

    field_annotation_time_ms: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="fieldAnnotationTimeMs")
    ] = pydantic.Field(alias="fieldAnnotationTimeMs", default=None)
    """
    The time taken to annotate the fields in the document.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.file import File
from ...types.next_page_token import NextPageToken


class FileListResponse(UncheckedBaseModel):
    success: bool
    files: typing.List[File]
    next_page_token: typing_extensions.Annotated[
        typing.Optional[NextPageToken], FieldMetadata(alias="nextPageToken")
    ] = pydantic.Field(alias="nextPageToken", default=None)

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .insight_type import InsightType


class Insight(UncheckedBaseModel):
    type: InsightType = pydantic.Field()
    """
    The type of insight:
    - `reasoning`: Model reasoning about the extraction decision
    - `issue`: A potential problem or concern identified by the agentic confidence system
    - `review_summary`: A summary explanation from the agentic confidence system about why the field may need manual review
    """

    content: str = pydantic.Field()
    """
    The content of the insight.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .page_ranges import PageRanges


class ParseConfigAdvancedOptions(UncheckedBaseModel):
    page_rotation_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="pageRotationEnabled")
    ] = pydantic.Field(alias="pageRotationEnabled", default=None)
    """
    Whether to automatically detect and correct page rotation.
    """

    agentic_ocr_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="agenticOcrEnabled")
    ] = pydantic.Field(alias="agenticOcrEnabled", default=None)
    """
    Whether to enable agentic OCR corrections using VLM-based review and correction of OCR errors for messy handwriting and poorly scanned text.
    """

    page_ranges: typing_extensions.Annotated[typing.Optional[PageRanges], FieldMetadata(alias="pageRanges")] = (
        pydantic.Field(alias="pageRanges", default=None)
    )
    vertical_grouping_threshold: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="verticalGroupingThreshold")
    ] = pydantic.Field(alias="verticalGroupingThreshold", default=None)
    """
    Multiplier for the Y-axis threshold used to determine if text blocks should be placed on the same line or not (0.1-5.0, default 1.0). Higher values group elements that are further apart vertically. Only applies when the spatial target is set.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.edit_run import EditRun
from ..types.edit_run_status import EditRunStatus
from .raw_client import AsyncRawEditClient, RawEditClient
from .types.edit_create_async_request_config import EditCreateAsyncRequestConfig
from .types.edit_create_async_request_file import EditCreateAsyncRequestFile
from .types.edit_create_request_config import EditCreateRequestConfig
from .types.edit_create_request_file import EditCreateRequestFile
from .types.edit_delete_response import EditDeleteResponse
from .types.edit_get_response import EditGetResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class EditClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawEditClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawEditClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawEditClient
        """
        return self._raw_client

    def create(
        self,
        *,
        file: EditCreateRequestFile,
        config: typing.Optional[EditCreateRequestConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EditRun:
        """
        Edit and manipulate PDF documents by detecting and filling form fields.
        This is a synchronous endpoint that will wait for the edit operation to complete (up to 5 minutes) before returning results. For longer operations, use the [Edit File Async](/developers/api-reference/edit-endpoints/edit-file-async) endpoint.

        Parameters
        ----------
        file : EditCreateRequestFile
            A file object containing either a URL or a fileId.

        config : typing.Optional[EditCreateRequestConfig]
            Configuration for the edit operation. Field values should be specified using `extend_edit:value` on each field in the schema.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditRun
            Successfully edited file

        Examples
        --------
        from extend_ai import Extend
        from extend_ai.edit import EditCreateRequestFile

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.edit.create(
            file=EditCreateRequestFile(),
        )
        """
        _response = self._raw_client.create(file=file, config=config, request_options=request_options)
        return _response.data

    def create_async(
        self,
        *,
        file: EditCreateAsyncRequestFile,
        config: typing.Optional[EditCreateAsyncRequestConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EditRunStatus:
        """
        Edit and manipulate PDF documents **asynchronously** by filling forms, adding/modifying text fields, and applying structured changes.

        The Edit Async endpoint allows you to convert and edit documents asynchronously and get an edit run ID that can be used to check status and retrieve results with the [Get Edit Run](/developers/api-reference/edit-endpoints/get-edit-run) endpoint.

        This is useful for:
        * Large files that may take longer to process
        * Avoiding timeout issues with synchronous editing
        * Processing multiple files in parallel

        Parameters
        ----------
        file : EditCreateAsyncRequestFile
            A file object containing either a URL or a fileId.

        config : typing.Optional[EditCreateAsyncRequestConfig]
            Configuration for the edit operation. Field values should be specified using `extend_edit:value` on each field in the schema.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditRunStatus
            Successfully initiated edit run

        Examples
        --------
        from extend_ai import Extend
        from extend_ai.edit import EditCreateAsyncRequestFile

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.edit.create_async(
            file=EditCreateAsyncRequestFile(),
        )
        """
        _response = self._raw_client.create_async(file=file, config=config, request_options=request_options)
        return _response.data

    def get(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> EditGetResponse:
        """
        Retrieve the status and results of an edit run.

        Use this endpoint to get results for an edit run that has already completed, or to check on the status of an asynchronous edit run initiated via the [Edit File Asynchronously](/developers/api-reference/edit-endpoints/edit-file-async) endpoint.

        If editing is still in progress, you'll receive a response with just the status. Once complete, you'll receive the full edited file information in the response.

        Parameters
        ----------
        id : str
            The unique identifier for the edit run.

            Example: `"edit_run_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditGetResponse
            Successfully retrieved edit run

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.edit.get(
            id="edit_run_id_here",
        )
        """
        _response = self._raw_client.get(id, request_options=request_options)
        return _response.data

    def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> EditDeleteResponse:
        """
        Delete an edit run and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than relying on automated data retention policies, or to make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the edit run to delete.

            Example: `"edit_run_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditDeleteResponse
            Successfully deleted edit run

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.edit.delete(
            id="edit_run_id_here",
        )
        """
        _response = self._raw_client.delete(id, request_options=request_options)
        return _response.data


class AsyncEditClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawEditClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawEditClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawEditClient
        """
        return self._raw_client

    async def create(
        self,
        *,
        file: EditCreateRequestFile,
        config: typing.Optional[EditCreateRequestConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EditRun:
        """
        Edit and manipulate PDF documents by detecting and filling form fields.
        This is a synchronous endpoint that will wait for the edit operation to complete (up to 5 minutes) before returning results. For longer operations, use the [Edit File Async](/developers/api-reference/edit-endpoints/edit-file-async) endpoint.

        Parameters
        ----------
        file : EditCreateRequestFile
            A file object containing either a URL or a fileId.

        config : typing.Optional[EditCreateRequestConfig]
            Configuration for the edit operation. Field values should be specified using `extend_edit:value` on each field in the schema.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditRun
            Successfully edited file

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend
        from extend_ai.edit import EditCreateRequestFile

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.edit.create(
                file=EditCreateRequestFile(),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(file=file, config=config, request_options=request_options)
        return _response.data

    async def create_async(
        self,
        *,
        file: EditCreateAsyncRequestFile,
        config: typing.Optional[EditCreateAsyncRequestConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EditRunStatus:
        """
        Edit and manipulate PDF documents **asynchronously** by filling forms, adding/modifying text fields, and applying structured changes.

        The Edit Async endpoint allows you to convert and edit documents asynchronously and get an edit run ID that can be used to check status and retrieve results with the [Get Edit Run](/developers/api-reference/edit-endpoints/get-edit-run) endpoint.

        This is useful for:
        * Large files that may take longer to process
        * Avoiding timeout issues with synchronous editing
        * Processing multiple files in parallel

        Parameters
        ----------
        file : EditCreateAsyncRequestFile
            A file object containing either a URL or a fileId.

        config : typing.Optional[EditCreateAsyncRequestConfig]
            Configuration for the edit operation. Field values should be specified using `extend_edit:value` on each field in the schema.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditRunStatus
            Successfully initiated edit run

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend
        from extend_ai.edit import EditCreateAsyncRequestFile

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.edit.create_async(
                file=EditCreateAsyncRequestFile(),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_async(file=file, config=config, request_options=request_options)
        return _response.data

    async def get(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> EditGetResponse:
        """
        Retrieve the status and results of an edit run.

        Use this endpoint to get results for an edit run that has already completed, or to check on the status of an asynchronous edit run initiated via the [Edit File Asynchronously](/developers/api-reference/edit-endpoints/edit-file-async) endpoint.

        If editing is still in progress, you'll receive a response with just the status. Once complete, you'll receive the full edited file information in the response.

        Parameters
        ----------
        id : str
            The unique identifier for the edit run.

            Example: `"edit_run_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditGetResponse
            Successfully retrieved edit run

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.edit.get(
                id="edit_run_id_here",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(id, request_options=request_options)
        return _response.data

    async def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> EditDeleteResponse:
        """
        Delete an edit run and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than relying on automated data retention policies, or to make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the edit run to delete.

            Example: `"edit_run_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditDeleteResponse
            Successfully deleted edit run

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.edit.delete(
                id="edit_run_id_here",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class WorkflowRunCredits(UncheckedBaseModel):
    """
    These are usage credits for workflow runs.

    This field will not be returned for workflow runs created before October 7, 2025, or for customers on legacy billing systems.

    For more details on how credits work, see our [Credits Guide](/product/general/how-credits-work).
    """

    credits: float = pydantic.Field()
    """
    The number of credits consumed for processing in this workflow run.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .optimizer_batch_processor_run_result_processor_config import OptimizerBatchProcessorRunResultProcessorConfig
from .optimizer_run_metrics import OptimizerRunMetrics


class OptimizerBatchProcessorRunResult(UncheckedBaseModel):
    batch_processor_run_id: typing_extensions.Annotated[str, FieldMetadata(alias="batchProcessorRunId")] = (
        pydantic.Field(alias="batchProcessorRunId")
    )
    """
    Unique identifier for the batch processor run
    """

    is_baseline: typing_extensions.Annotated[bool, FieldMetadata(alias="isBaseline")] = pydantic.Field(
        alias="isBaseline"
    )
    """
    Whether this is the baseline (original) configuration
    """

    processor_config: typing_extensions.Annotated[
        OptimizerBatchProcessorRunResultProcessorConfig, FieldMetadata(alias="processorConfig")
    ] = pydantic.Field(alias="processorConfig")
    """
    Processor configuration used for this run
    """

    metrics: OptimizerRunMetrics

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(OptimizerBatchProcessorRunResult)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .optimizer_batch_processor_run_result import OptimizerBatchProcessorRunResult
from .optimizer_run_agent_type import OptimizerRunAgentType
from .optimizer_run_status import OptimizerRunStatus


class OptimizerRun(UncheckedBaseModel):
    agent_run_id: typing_extensions.Annotated[str, FieldMetadata(alias="agentRunId")] = pydantic.Field(
        alias="agentRunId"
    )
    """
    Unique identifier for the optimizer run
    """

    processor_id: typing_extensions.Annotated[str, FieldMetadata(alias="processorId")] = pydantic.Field(
        alias="processorId"
    )
    """
    ID of the processor being optimized
    """

    processor_version_id: typing_extensions.Annotated[str, FieldMetadata(alias="processorVersionId")] = pydantic.Field(
        alias="processorVersionId"
    )
    """
    ID of the processor version being optimized
    """

    eval_set_id: typing_extensions.Annotated[str, FieldMetadata(alias="evalSetId")] = pydantic.Field(alias="evalSetId")
    """
    ID of the evaluation set used
    """

    agent_type: typing_extensions.Annotated[OptimizerRunAgentType, FieldMetadata(alias="agentType")] = pydantic.Field(
        alias="agentType"
    )
    """
    Type of optimizer agent that ran
    """

    status: OptimizerRunStatus = pydantic.Field()
    """
    Current status of the optimizer run
    """

    created_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="createdAt")] = pydantic.Field(
        alias="createdAt"
    )
    """
    ISO 8601 timestamp of when the run was created
    """

    updated_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="updatedAt")] = pydantic.Field(
        alias="updatedAt"
    )
    """
    ISO 8601 timestamp of when the run was last updated
    """

    batch_processor_runs: typing_extensions.Annotated[
        typing.Optional[typing.List[OptimizerBatchProcessorRunResult]], FieldMetadata(alias="batchProcessorRuns")
    ] = pydantic.Field(alias="batchProcessorRuns", default=None)
    """
    Array of batch processor run results. Each run represents one iteration of the optimization process.
    The first result (with `isBaseline: true`) is the baseline configuration.
    Subsequent results are optimization attempts, sorted chronologically.
    Only present when status is `PROCESSED`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(OptimizerRun)



# This file was auto-generated by Fern from our API Definition.

import typing

from .classification_field_metrics import ClassificationFieldMetrics
from .extraction_field_metrics import ExtractionFieldMetrics

OptimizerRunMetricsFieldsItem = typing.Union[ExtractionFieldMetrics, ClassificationFieldMetrics]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .array_strategy_type import ArrayStrategyType


class ArrayStrategy(UncheckedBaseModel):
    type: ArrayStrategyType = pydantic.Field()
    """
    The strategy type for handling large array use cases. For most use cases this should be left null, or should be set to `large_array_heuristics`. If you're unsure of what your use case needs, reach out to the Extend team for help.
    - `large_array_heuristics`: Optimized for documents with very large arrays, but where latency matters. 
    
      This strategy uses specialized heuristics around chunking, tables, and merging to handle large arrays efficiently over large documents.
    
    - `large_array_max_context`: Optimizes for accuracy over latency in documents with very large arrays. 
    
      This strategy will do multiple passes through the entire document to ensure there is no context loss across any chunks/pages, maximizing accuracy for complex array extraction, but adding material latency.
    
    - `large_array_overlap_context`: Balances accuracy and latency in documents with very large arrays. 
    
      This strategy will always maintain surrounding/overlapping page context for every chunk/page that is extracted, eliminating array failure modes from context loss across page boundaries.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

ArrayStrategyType = typing.Union[
    typing.Literal["large_array_heuristics", "large_array_max_context", "large_array_overlap_context"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .api_version_enum import ApiVersionEnum
    from .array_strategy import ArrayStrategy
    from .array_strategy_type import ArrayStrategyType
    from .bad_request_error_body import BadRequestErrorBody
    from .bad_request_error_body_code import BadRequestErrorBodyCode
    from .base_metrics import BaseMetrics
    from .batch_processor_run import BatchProcessorRun
    from .batch_processor_run_metrics import BatchProcessorRunMetrics
    from .batch_processor_run_options import BatchProcessorRunOptions
    from .batch_processor_run_source import BatchProcessorRunSource
    from .batch_processor_run_status import BatchProcessorRunStatus
    from .batch_workflow_run_file_input import BatchWorkflowRunFileInput
    from .block import Block
    from .block_bounding_box import BlockBoundingBox
    from .block_details import BlockDetails
    from .block_metadata import BlockMetadata
    from .block_metadata_page import BlockMetadataPage
    from .block_polygon_item import BlockPolygonItem
    from .block_type import BlockType
    from .chunk import Chunk
    from .chunk_metadata import ChunkMetadata
    from .chunk_metadata_page_range import ChunkMetadataPageRange
    from .chunk_type import ChunkType
    from .citation import Citation
    from .classification import Classification
    from .classification_advanced_options import ClassificationAdvancedOptions
    from .classification_advanced_options_context import ClassificationAdvancedOptionsContext
    from .classification_config import ClassificationConfig
    from .classification_config_base_processor import ClassificationConfigBaseProcessor
    from .classification_field_metrics import ClassificationFieldMetrics
    from .classifier_output import ClassifierOutput
    from .classify_metrics import ClassifyMetrics
    from .classify_optimizer_options import ClassifyOptimizerOptions
    from .document_processor_run_credits import DocumentProcessorRunCredits
    from .edit_bounding_box import EditBoundingBox
    from .edit_error import EditError
    from .edit_error_code import EditErrorCode
    from .edit_json_schema import EditJsonSchema
    from .edit_json_schema_extend_edit_field_type import EditJsonSchemaExtendEditFieldType
    from .edit_object_json_schema import EditObjectJsonSchema
    from .edit_root_json_schema import EditRootJsonSchema
    from .edit_run import EditRun
    from .edit_run_config import EditRunConfig
    from .edit_run_config_advanced_options import EditRunConfigAdvancedOptions
    from .edit_run_edited_file import EditRunEditedFile
    from .edit_run_metrics import EditRunMetrics
    from .edit_run_status import EditRunStatus
    from .edit_run_status_status import EditRunStatusStatus
    from .edit_run_usage import EditRunUsage
    from .edit_text_options import EditTextOptions
    from .empty_block_details import EmptyBlockDetails
    from .enum import Enum
    from .enum_option import EnumOption
    from .error import Error
    from .evaluation_set import EvaluationSet
    from .evaluation_set_item import EvaluationSetItem
    from .excel_sheet_range import ExcelSheetRange
    from .extend_error import ExtendError
    from .extract_chunking_options import ExtractChunkingOptions
    from .extract_chunking_options_chunk_selection_strategy import ExtractChunkingOptionsChunkSelectionStrategy
    from .extract_chunking_options_chunking_strategy import ExtractChunkingOptionsChunkingStrategy
    from .extract_metrics import ExtractMetrics
    from .extract_metrics_field_metrics import ExtractMetricsFieldMetrics
    from .extract_optimizer_options import ExtractOptimizerOptions
    from .extraction_advanced_options import ExtractionAdvancedOptions
    from .extraction_advanced_options_array_citation_strategy import ExtractionAdvancedOptionsArrayCitationStrategy
    from .extraction_advanced_options_excel_sheet_selection_strategy import (
        ExtractionAdvancedOptionsExcelSheetSelectionStrategy,
    )
    from .extraction_advanced_options_review_agent import ExtractionAdvancedOptionsReviewAgent
    from .extraction_config import ExtractionConfig
    from .extraction_config_base_processor import ExtractionConfigBaseProcessor
    from .extraction_field import ExtractionField
    from .extraction_field_metrics import ExtractionFieldMetrics
    from .extraction_field_result import ExtractionFieldResult
    from .extraction_field_result_reference import ExtractionFieldResultReference
    from .extraction_field_result_reference_bounding_boxes_item import ExtractionFieldResultReferenceBoundingBoxesItem
    from .extraction_field_result_type import ExtractionFieldResultType
    from .extraction_field_type import ExtractionFieldType
    from .extraction_output import ExtractionOutput
    from .extraction_output_edits import ExtractionOutputEdits
    from .fields_array_output import FieldsArrayOutput
    from .figure_details import FigureDetails
    from .figure_details_figure_type import FigureDetailsFigureType
    from .file import File
    from .file_contents import FileContents
    from .file_contents_pages_item import FileContentsPagesItem
    from .file_contents_sheets_item import FileContentsSheetsItem
    from .file_credits import FileCredits
    from .file_metadata import FileMetadata
    from .file_metadata_parent_split import FileMetadataParentSplit
    from .file_type import FileType
    from .insight import Insight
    from .insight_type import InsightType
    from .json_object import JsonObject
    from .json_output import JsonOutput
    from .json_output_metadata_value import JsonOutputMetadataValue
    from .json_output_metadata_value_citations_item import JsonOutputMetadataValueCitationsItem
    from .json_output_metadata_value_citations_item_polygon_item import JsonOutputMetadataValueCitationsItemPolygonItem
    from .list_processors_processor import ListProcessorsProcessor
    from .list_processors_processor_version import ListProcessorsProcessorVersion
    from .list_processors_response import ListProcessorsResponse
    from .max_page_size import MaxPageSize
    from .next_page_token import NextPageToken
    from .optimizer_batch_processor_run_result import OptimizerBatchProcessorRunResult
    from .optimizer_batch_processor_run_result_processor_config import (
        OptimizerBatchProcessorRunResultProcessorConfig,
        OptimizerBatchProcessorRunResultProcessorConfig_Classify,
        OptimizerBatchProcessorRunResultProcessorConfig_Extract,
    )
    from .optimizer_run import OptimizerRun
    from .optimizer_run_agent_type import OptimizerRunAgentType
    from .optimizer_run_metrics import OptimizerRunMetrics
    from .optimizer_run_metrics_fields_item import OptimizerRunMetricsFieldsItem
    from .optimizer_run_status import OptimizerRunStatus
    from .output_metadata import OutputMetadata
    from .output_metadata_value import OutputMetadataValue
    from .page_ranges import PageRanges
    from .page_ranges_item import PageRangesItem
    from .parse_async_request_file import ParseAsyncRequestFile
    from .parse_config import ParseConfig
    from .parse_config_advanced_options import ParseConfigAdvancedOptions
    from .parse_config_block_options import ParseConfigBlockOptions
    from .parse_config_block_options_figures import ParseConfigBlockOptionsFigures
    from .parse_config_block_options_tables import ParseConfigBlockOptionsTables
    from .parse_config_block_options_tables_target_format import ParseConfigBlockOptionsTablesTargetFormat
    from .parse_config_block_options_text import ParseConfigBlockOptionsText
    from .parse_config_chunking_strategy import ParseConfigChunkingStrategy
    from .parse_config_chunking_strategy_options import ParseConfigChunkingStrategyOptions
    from .parse_config_chunking_strategy_type import ParseConfigChunkingStrategyType
    from .parse_config_target import ParseConfigTarget
    from .parse_error import ParseError
    from .parse_error_code import ParseErrorCode
    from .parse_request_file import ParseRequestFile
    from .parse_request_response_type import ParseRequestResponseType
    from .parser_run import ParserRun
    from .parser_run_credits import ParserRunCredits
    from .parser_run_metrics import ParserRunMetrics
    from .parser_run_status import ParserRunStatus
    from .parser_run_status_enum import ParserRunStatusEnum
    from .parser_run_status_status import ParserRunStatusStatus
    from .polygon import Polygon
    from .processor import Processor
    from .processor_id import ProcessorId
    from .processor_output import ProcessorOutput
    from .processor_run import ProcessorRun
    from .processor_run_config import (
        ProcessorRunConfig,
        ProcessorRunConfig_Classify,
        ProcessorRunConfig_Extract,
        ProcessorRunConfig_Splitter,
    )
    from .processor_run_file_input import ProcessorRunFileInput
    from .processor_run_merged_processors_item import ProcessorRunMergedProcessorsItem
    from .processor_run_summary import ProcessorRunSummary
    from .processor_run_summary_type import ProcessorRunSummaryType
    from .processor_run_type import ProcessorRunType
    from .processor_status import ProcessorStatus
    from .processor_type import ProcessorType
    from .processor_version import ProcessorVersion
    from .processor_version_config import (
        ProcessorVersionConfig,
        ProcessorVersionConfig_Classify,
        ProcessorVersionConfig_Extract,
        ProcessorVersionConfig_Splitter,
    )
    from .provided_classifier_output import ProvidedClassifierOutput
    from .provided_extraction_field_result import ProvidedExtractionFieldResult
    from .provided_extraction_field_result_type import ProvidedExtractionFieldResultType
    from .provided_extraction_output import ProvidedExtractionOutput
    from .provided_fields_array_output import ProvidedFieldsArrayOutput
    from .provided_json_output import ProvidedJsonOutput
    from .provided_processor_output import ProvidedProcessorOutput
    from .provided_splitter_output import ProvidedSplitterOutput
    from .provided_splitter_output_splits_item import ProvidedSplitterOutputSplitsItem
    from .sort_by_enum import SortByEnum
    from .sort_dir_enum import SortDirEnum
    from .splitter_advanced_options import SplitterAdvancedOptions
    from .splitter_advanced_options_split_method import SplitterAdvancedOptionsSplitMethod
    from .splitter_config import SplitterConfig
    from .splitter_config_base_processor import SplitterConfigBaseProcessor
    from .splitter_metrics import SplitterMetrics
    from .splitter_output import SplitterOutput
    from .splitter_output_splits_item import SplitterOutputSplitsItem
    from .step_run import StepRun
    from .step_run_output import StepRunOutput
    from .step_run_output_rules_item import StepRunOutputRulesItem
    from .step_run_output_rules_item_failure_reason import StepRunOutputRulesItemFailureReason
    from .step_run_status import StepRunStatus
    from .step_run_step import StepRunStep
    from .step_run_step_type import StepRunStepType
    from .table_cell_details import TableCellDetails
    from .table_details import TableDetails
    from .too_many_requests_error_body import TooManyRequestsErrorBody
    from .webhook_event import WebhookEvent
    from .webhook_event_event_type import WebhookEventEventType
    from .webhook_event_payload import WebhookEventPayload
    from .webhook_event_processor import WebhookEventProcessor
    from .webhook_event_processor_event_type import WebhookEventProcessorEventType
    from .webhook_event_processor_run import WebhookEventProcessorRun
    from .webhook_event_processor_run_event_type import WebhookEventProcessorRunEventType
    from .webhook_event_processor_version import WebhookEventProcessorVersion
    from .webhook_event_workflow import WebhookEventWorkflow
    from .webhook_event_workflow_event_type import WebhookEventWorkflowEventType
    from .webhook_event_workflow_run import WebhookEventWorkflowRun
    from .webhook_event_workflow_run_event_type import WebhookEventWorkflowRunEventType
    from .workflow import Workflow
    from .workflow_run import WorkflowRun
    from .workflow_run_credits import WorkflowRunCredits
    from .workflow_run_file_input import WorkflowRunFileInput
    from .workflow_run_file_input_outputs_item import WorkflowRunFileInputOutputsItem
    from .workflow_run_summary import WorkflowRunSummary
    from .workflow_status import WorkflowStatus
_dynamic_imports: typing.Dict[str, str] = {
    "ApiVersionEnum": ".api_version_enum",
    "ArrayStrategy": ".array_strategy",
    "ArrayStrategyType": ".array_strategy_type",
    "BadRequestErrorBody": ".bad_request_error_body",
    "BadRequestErrorBodyCode": ".bad_request_error_body_code",
    "BaseMetrics": ".base_metrics",
    "BatchProcessorRun": ".batch_processor_run",
    "BatchProcessorRunMetrics": ".batch_processor_run_metrics",
    "BatchProcessorRunOptions": ".batch_processor_run_options",
    "BatchProcessorRunSource": ".batch_processor_run_source",
    "BatchProcessorRunStatus": ".batch_processor_run_status",
    "BatchWorkflowRunFileInput": ".batch_workflow_run_file_input",
    "Block": ".block",
    "BlockBoundingBox": ".block_bounding_box",
    "BlockDetails": ".block_details",
    "BlockMetadata": ".block_metadata",
    "BlockMetadataPage": ".block_metadata_page",
    "BlockPolygonItem": ".block_polygon_item",
    "BlockType": ".block_type",
    "Chunk": ".chunk",
    "ChunkMetadata": ".chunk_metadata",
    "ChunkMetadataPageRange": ".chunk_metadata_page_range",
    "ChunkType": ".chunk_type",
    "Citation": ".citation",
    "Classification": ".classification",
    "ClassificationAdvancedOptions": ".classification_advanced_options",
    "ClassificationAdvancedOptionsContext": ".classification_advanced_options_context",
    "ClassificationConfig": ".classification_config",
    "ClassificationConfigBaseProcessor": ".classification_config_base_processor",
    "ClassificationFieldMetrics": ".classification_field_metrics",
    "ClassifierOutput": ".classifier_output",
    "ClassifyMetrics": ".classify_metrics",
    "ClassifyOptimizerOptions": ".classify_optimizer_options",
    "DocumentProcessorRunCredits": ".document_processor_run_credits",
    "EditBoundingBox": ".edit_bounding_box",
    "EditError": ".edit_error",
    "EditErrorCode": ".edit_error_code",
    "EditJsonSchema": ".edit_json_schema",
    "EditJsonSchemaExtendEditFieldType": ".edit_json_schema_extend_edit_field_type",
    "EditObjectJsonSchema": ".edit_object_json_schema",
    "EditRootJsonSchema": ".edit_root_json_schema",
    "EditRun": ".edit_run",
    "EditRunConfig": ".edit_run_config",
    "EditRunConfigAdvancedOptions": ".edit_run_config_advanced_options",
    "EditRunEditedFile": ".edit_run_edited_file",
    "EditRunMetrics": ".edit_run_metrics",
    "EditRunStatus": ".edit_run_status",
    "EditRunStatusStatus": ".edit_run_status_status",
    "EditRunUsage": ".edit_run_usage",
    "EditTextOptions": ".edit_text_options",
    "EmptyBlockDetails": ".empty_block_details",
    "Enum": ".enum",
    "EnumOption": ".enum_option",
    "Error": ".error",
    "EvaluationSet": ".evaluation_set",
    "EvaluationSetItem": ".evaluation_set_item",
    "ExcelSheetRange": ".excel_sheet_range",
    "ExtendError": ".extend_error",
    "ExtractChunkingOptions": ".extract_chunking_options",
    "ExtractChunkingOptionsChunkSelectionStrategy": ".extract_chunking_options_chunk_selection_strategy",
    "ExtractChunkingOptionsChunkingStrategy": ".extract_chunking_options_chunking_strategy",
    "ExtractMetrics": ".extract_metrics",
    "ExtractMetricsFieldMetrics": ".extract_metrics_field_metrics",
    "ExtractOptimizerOptions": ".extract_optimizer_options",
    "ExtractionAdvancedOptions": ".extraction_advanced_options",
    "ExtractionAdvancedOptionsArrayCitationStrategy": ".extraction_advanced_options_array_citation_strategy",
    "ExtractionAdvancedOptionsExcelSheetSelectionStrategy": ".extraction_advanced_options_excel_sheet_selection_strategy",
    "ExtractionAdvancedOptionsReviewAgent": ".extraction_advanced_options_review_agent",
    "ExtractionConfig": ".extraction_config",
    "ExtractionConfigBaseProcessor": ".extraction_config_base_processor",
    "ExtractionField": ".extraction_field",
    "ExtractionFieldMetrics": ".extraction_field_metrics",
    "ExtractionFieldResult": ".extraction_field_result",
    "ExtractionFieldResultReference": ".extraction_field_result_reference",
    "ExtractionFieldResultReferenceBoundingBoxesItem": ".extraction_field_result_reference_bounding_boxes_item",
    "ExtractionFieldResultType": ".extraction_field_result_type",
    "ExtractionFieldType": ".extraction_field_type",
    "ExtractionOutput": ".extraction_output",
    "ExtractionOutputEdits": ".extraction_output_edits",
    "FieldsArrayOutput": ".fields_array_output",
    "FigureDetails": ".figure_details",
    "FigureDetailsFigureType": ".figure_details_figure_type",
    "File": ".file",
    "FileContents": ".file_contents",
    "FileContentsPagesItem": ".file_contents_pages_item",
    "FileContentsSheetsItem": ".file_contents_sheets_item",
    "FileCredits": ".file_credits",
    "FileMetadata": ".file_metadata",
    "FileMetadataParentSplit": ".file_metadata_parent_split",
    "FileType": ".file_type",
    "Insight": ".insight",
    "InsightType": ".insight_type",
    "JsonObject": ".json_object",
    "JsonOutput": ".json_output",
    "JsonOutputMetadataValue": ".json_output_metadata_value",
    "JsonOutputMetadataValueCitationsItem": ".json_output_metadata_value_citations_item",
    "JsonOutputMetadataValueCitationsItemPolygonItem": ".json_output_metadata_value_citations_item_polygon_item",
    "ListProcessorsProcessor": ".list_processors_processor",
    "ListProcessorsProcessorVersion": ".list_processors_processor_version",
    "ListProcessorsResponse": ".list_processors_response",
    "MaxPageSize": ".max_page_size",
    "NextPageToken": ".next_page_token",
    "OptimizerBatchProcessorRunResult": ".optimizer_batch_processor_run_result",
    "OptimizerBatchProcessorRunResultProcessorConfig": ".optimizer_batch_processor_run_result_processor_config",
    "OptimizerBatchProcessorRunResultProcessorConfig_Classify": ".optimizer_batch_processor_run_result_processor_config",
    "OptimizerBatchProcessorRunResultProcessorConfig_Extract": ".optimizer_batch_processor_run_result_processor_config",
    "OptimizerRun": ".optimizer_run",
    "OptimizerRunAgentType": ".optimizer_run_agent_type",
    "OptimizerRunMetrics": ".optimizer_run_metrics",
    "OptimizerRunMetricsFieldsItem": ".optimizer_run_metrics_fields_item",
    "OptimizerRunStatus": ".optimizer_run_status",
    "OutputMetadata": ".output_metadata",
    "OutputMetadataValue": ".output_metadata_value",
    "PageRanges": ".page_ranges",
    "PageRangesItem": ".page_ranges_item",
    "ParseAsyncRequestFile": ".parse_async_request_file",
    "ParseConfig": ".parse_config",
    "ParseConfigAdvancedOptions": ".parse_config_advanced_options",
    "ParseConfigBlockOptions": ".parse_config_block_options",
    "ParseConfigBlockOptionsFigures": ".parse_config_block_options_figures",
    "ParseConfigBlockOptionsTables": ".parse_config_block_options_tables",
    "ParseConfigBlockOptionsTablesTargetFormat": ".parse_config_block_options_tables_target_format",
    "ParseConfigBlockOptionsText": ".parse_config_block_options_text",
    "ParseConfigChunkingStrategy": ".parse_config_chunking_strategy",
    "ParseConfigChunkingStrategyOptions": ".parse_config_chunking_strategy_options",
    "ParseConfigChunkingStrategyType": ".parse_config_chunking_strategy_type",
    "ParseConfigTarget": ".parse_config_target",
    "ParseError": ".parse_error",
    "ParseErrorCode": ".parse_error_code",
    "ParseRequestFile": ".parse_request_file",
    "ParseRequestResponseType": ".parse_request_response_type",
    "ParserRun": ".parser_run",
    "ParserRunCredits": ".parser_run_credits",
    "ParserRunMetrics": ".parser_run_metrics",
    "ParserRunStatus": ".parser_run_status",
    "ParserRunStatusEnum": ".parser_run_status_enum",
    "ParserRunStatusStatus": ".parser_run_status_status",
    "Polygon": ".polygon",
    "Processor": ".processor",
    "ProcessorId": ".processor_id",
    "ProcessorOutput": ".processor_output",
    "ProcessorRun": ".processor_run",
    "ProcessorRunConfig": ".processor_run_config",
    "ProcessorRunConfig_Classify": ".processor_run_config",
    "ProcessorRunConfig_Extract": ".processor_run_config",
    "ProcessorRunConfig_Splitter": ".processor_run_config",
    "ProcessorRunFileInput": ".processor_run_file_input",
    "ProcessorRunMergedProcessorsItem": ".processor_run_merged_processors_item",
    "ProcessorRunSummary": ".processor_run_summary",
    "ProcessorRunSummaryType": ".processor_run_summary_type",
    "ProcessorRunType": ".processor_run_type",
    "ProcessorStatus": ".processor_status",
    "ProcessorType": ".processor_type",
    "ProcessorVersion": ".processor_version",
    "ProcessorVersionConfig": ".processor_version_config",
    "ProcessorVersionConfig_Classify": ".processor_version_config",
    "ProcessorVersionConfig_Extract": ".processor_version_config",
    "ProcessorVersionConfig_Splitter": ".processor_version_config",
    "ProvidedClassifierOutput": ".provided_classifier_output",
    "ProvidedExtractionFieldResult": ".provided_extraction_field_result",
    "ProvidedExtractionFieldResultType": ".provided_extraction_field_result_type",
    "ProvidedExtractionOutput": ".provided_extraction_output",
    "ProvidedFieldsArrayOutput": ".provided_fields_array_output",
    "ProvidedJsonOutput": ".provided_json_output",
    "ProvidedProcessorOutput": ".provided_processor_output",
    "ProvidedSplitterOutput": ".provided_splitter_output",
    "ProvidedSplitterOutputSplitsItem": ".provided_splitter_output_splits_item",
    "SortByEnum": ".sort_by_enum",
    "SortDirEnum": ".sort_dir_enum",
    "SplitterAdvancedOptions": ".splitter_advanced_options",
    "SplitterAdvancedOptionsSplitMethod": ".splitter_advanced_options_split_method",
    "SplitterConfig": ".splitter_config",
    "SplitterConfigBaseProcessor": ".splitter_config_base_processor",
    "SplitterMetrics": ".splitter_metrics",
    "SplitterOutput": ".splitter_output",
    "SplitterOutputSplitsItem": ".splitter_output_splits_item",
    "StepRun": ".step_run",
    "StepRunOutput": ".step_run_output",
    "StepRunOutputRulesItem": ".step_run_output_rules_item",
    "StepRunOutputRulesItemFailureReason": ".step_run_output_rules_item_failure_reason",
    "StepRunStatus": ".step_run_status",
    "StepRunStep": ".step_run_step",
    "StepRunStepType": ".step_run_step_type",
    "TableCellDetails": ".table_cell_details",
    "TableDetails": ".table_details",
    "TooManyRequestsErrorBody": ".too_many_requests_error_body",
    "WebhookEvent": ".webhook_event",
    "WebhookEventEventType": ".webhook_event_event_type",
    "WebhookEventPayload": ".webhook_event_payload",
    "WebhookEventProcessor": ".webhook_event_processor",
    "WebhookEventProcessorEventType": ".webhook_event_processor_event_type",
    "WebhookEventProcessorRun": ".webhook_event_processor_run",
    "WebhookEventProcessorRunEventType": ".webhook_event_processor_run_event_type",
    "WebhookEventProcessorVersion": ".webhook_event_processor_version",
    "WebhookEventWorkflow": ".webhook_event_workflow",
    "WebhookEventWorkflowEventType": ".webhook_event_workflow_event_type",
    "WebhookEventWorkflowRun": ".webhook_event_workflow_run",
    "WebhookEventWorkflowRunEventType": ".webhook_event_workflow_run_event_type",
    "Workflow": ".workflow",
    "WorkflowRun": ".workflow_run",
    "WorkflowRunCredits": ".workflow_run_credits",
    "WorkflowRunFileInput": ".workflow_run_file_input",
    "WorkflowRunFileInputOutputsItem": ".workflow_run_file_input_outputs_item",
    "WorkflowRunSummary": ".workflow_run_summary",
    "WorkflowStatus": ".workflow_status",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ApiVersionEnum",
    "ArrayStrategy",
    "ArrayStrategyType",
    "BadRequestErrorBody",
    "BadRequestErrorBodyCode",
    "BaseMetrics",
    "BatchProcessorRun",
    "BatchProcessorRunMetrics",
    "BatchProcessorRunOptions",
    "BatchProcessorRunSource",
    "BatchProcessorRunStatus",
    "BatchWorkflowRunFileInput",
    "Block",
    "BlockBoundingBox",
    "BlockDetails",
    "BlockMetadata",
    "BlockMetadataPage",
    "BlockPolygonItem",
    "BlockType",
    "Chunk",
    "ChunkMetadata",
    "ChunkMetadataPageRange",
    "ChunkType",
    "Citation",
    "Classification",
    "ClassificationAdvancedOptions",
    "ClassificationAdvancedOptionsContext",
    "ClassificationConfig",
    "ClassificationConfigBaseProcessor",
    "ClassificationFieldMetrics",
    "ClassifierOutput",
    "ClassifyMetrics",
    "ClassifyOptimizerOptions",
    "DocumentProcessorRunCredits",
    "EditBoundingBox",
    "EditError",
    "EditErrorCode",
    "EditJsonSchema",
    "EditJsonSchemaExtendEditFieldType",
    "EditObjectJsonSchema",
    "EditRootJsonSchema",
    "EditRun",
    "EditRunConfig",
    "EditRunConfigAdvancedOptions",
    "EditRunEditedFile",
    "EditRunMetrics",
    "EditRunStatus",
    "EditRunStatusStatus",
    "EditRunUsage",
    "EditTextOptions",
    "EmptyBlockDetails",
    "Enum",
    "EnumOption",
    "Error",
    "EvaluationSet",
    "EvaluationSetItem",
    "ExcelSheetRange",
    "ExtendError",
    "ExtractChunkingOptions",
    "ExtractChunkingOptionsChunkSelectionStrategy",
    "ExtractChunkingOptionsChunkingStrategy",
    "ExtractMetrics",
    "ExtractMetricsFieldMetrics",
    "ExtractOptimizerOptions",
    "ExtractionAdvancedOptions",
    "ExtractionAdvancedOptionsArrayCitationStrategy",
    "ExtractionAdvancedOptionsExcelSheetSelectionStrategy",
    "ExtractionAdvancedOptionsReviewAgent",
    "ExtractionConfig",
    "ExtractionConfigBaseProcessor",
    "ExtractionField",
    "ExtractionFieldMetrics",
    "ExtractionFieldResult",
    "ExtractionFieldResultReference",
    "ExtractionFieldResultReferenceBoundingBoxesItem",
    "ExtractionFieldResultType",
    "ExtractionFieldType",
    "ExtractionOutput",
    "ExtractionOutputEdits",
    "FieldsArrayOutput",
    "FigureDetails",
    "FigureDetailsFigureType",
    "File",
    "FileContents",
    "FileContentsPagesItem",
    "FileContentsSheetsItem",
    "FileCredits",
    "FileMetadata",
    "FileMetadataParentSplit",
    "FileType",
    "Insight",
    "InsightType",
    "JsonObject",
    "JsonOutput",
    "JsonOutputMetadataValue",
    "JsonOutputMetadataValueCitationsItem",
    "JsonOutputMetadataValueCitationsItemPolygonItem",
    "ListProcessorsProcessor",
    "ListProcessorsProcessorVersion",
    "ListProcessorsResponse",
    "MaxPageSize",
    "NextPageToken",
    "OptimizerBatchProcessorRunResult",
    "OptimizerBatchProcessorRunResultProcessorConfig",
    "OptimizerBatchProcessorRunResultProcessorConfig_Classify",
    "OptimizerBatchProcessorRunResultProcessorConfig_Extract",
    "OptimizerRun",
    "OptimizerRunAgentType",
    "OptimizerRunMetrics",
    "OptimizerRunMetricsFieldsItem",
    "OptimizerRunStatus",
    "OutputMetadata",
    "OutputMetadataValue",
    "PageRanges",
    "PageRangesItem",
    "ParseAsyncRequestFile",
    "ParseConfig",
    "ParseConfigAdvancedOptions",
    "ParseConfigBlockOptions",
    "ParseConfigBlockOptionsFigures",
    "ParseConfigBlockOptionsTables",
    "ParseConfigBlockOptionsTablesTargetFormat",
    "ParseConfigBlockOptionsText",
    "ParseConfigChunkingStrategy",
    "ParseConfigChunkingStrategyOptions",
    "ParseConfigChunkingStrategyType",
    "ParseConfigTarget",
    "ParseError",
    "ParseErrorCode",
    "ParseRequestFile",
    "ParseRequestResponseType",
    "ParserRun",
    "ParserRunCredits",
    "ParserRunMetrics",
    "ParserRunStatus",
    "ParserRunStatusEnum",
    "ParserRunStatusStatus",
    "Polygon",
    "Processor",
    "ProcessorId",
    "ProcessorOutput",
    "ProcessorRun",
    "ProcessorRunConfig",
    "ProcessorRunConfig_Classify",
    "ProcessorRunConfig_Extract",
    "ProcessorRunConfig_Splitter",
    "ProcessorRunFileInput",
    "ProcessorRunMergedProcessorsItem",
    "ProcessorRunSummary",
    "ProcessorRunSummaryType",
    "ProcessorRunType",
    "ProcessorStatus",
    "ProcessorType",
    "ProcessorVersion",
    "ProcessorVersionConfig",
    "ProcessorVersionConfig_Classify",
    "ProcessorVersionConfig_Extract",
    "ProcessorVersionConfig_Splitter",
    "ProvidedClassifierOutput",
    "ProvidedExtractionFieldResult",
    "ProvidedExtractionFieldResultType",
    "ProvidedExtractionOutput",
    "ProvidedFieldsArrayOutput",
    "ProvidedJsonOutput",
    "ProvidedProcessorOutput",
    "ProvidedSplitterOutput",
    "ProvidedSplitterOutputSplitsItem",
    "SortByEnum",
    "SortDirEnum",
    "SplitterAdvancedOptions",
    "SplitterAdvancedOptionsSplitMethod",
    "SplitterConfig",
    "SplitterConfigBaseProcessor",
    "SplitterMetrics",
    "SplitterOutput",
    "SplitterOutputSplitsItem",
    "StepRun",
    "StepRunOutput",
    "StepRunOutputRulesItem",
    "StepRunOutputRulesItemFailureReason",
    "StepRunStatus",
    "StepRunStep",
    "StepRunStepType",
    "TableCellDetails",
    "TableDetails",
    "TooManyRequestsErrorBody",
    "WebhookEvent",
    "WebhookEventEventType",
    "WebhookEventPayload",
    "WebhookEventProcessor",
    "WebhookEventProcessorEventType",
    "WebhookEventProcessorRun",
    "WebhookEventProcessorRunEventType",
    "WebhookEventProcessorVersion",
    "WebhookEventWorkflow",
    "WebhookEventWorkflowEventType",
    "WebhookEventWorkflowRun",
    "WebhookEventWorkflowRunEventType",
    "Workflow",
    "WorkflowRun",
    "WorkflowRunCredits",
    "WorkflowRunFileInput",
    "WorkflowRunFileInputOutputsItem",
    "WorkflowRunSummary",
    "WorkflowStatus",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.unchecked_base_model import construct_type
from ..errors.bad_request_error import BadRequestError
from ..errors.not_found_error import NotFoundError
from ..errors.unauthorized_error import UnauthorizedError
from ..types.error import Error
from .types.batch_processor_run_get_response import BatchProcessorRunGetResponse


class RawBatchProcessorRunClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[BatchProcessorRunGetResponse]:
        """
        Retrieve details about a batch processor run, including evaluation runs

        Parameters
        ----------
        id : str
            The unique identifier of the batch processor run to retrieve. The ID will always start with "bpr_".

            Example: `"bpr_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[BatchProcessorRunGetResponse]
            Successfully retrieved batch processor run
        """
        _response = self._client_wrapper.httpx_client.request(
            f"batch_processor_runs/{jsonable_encoder(id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    BatchProcessorRunGetResponse,
                    construct_type(
                        type_=BatchProcessorRunGetResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Error,
                        construct_type(
                            type_=Error,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawBatchProcessorRunClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[BatchProcessorRunGetResponse]:
        """
        Retrieve details about a batch processor run, including evaluation runs

        Parameters
        ----------
        id : str
            The unique identifier of the batch processor run to retrieve. The ID will always start with "bpr_".

            Example: `"bpr_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[BatchProcessorRunGetResponse]
            Successfully retrieved batch processor run
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"batch_processor_runs/{jsonable_encoder(id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    BatchProcessorRunGetResponse,
                    construct_type(
                        type_=BatchProcessorRunGetResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Error,
                        construct_type(
                            type_=Error,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class EditRunEditedFile(UncheckedBaseModel):
    """
    Information about the edited output file. Only present when status is "PROCESSED".
    """

    file_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="fileId")] = pydantic.Field(
        alias="fileId", default=None
    )
    """
    The identifier of the edited output file.
    """

    download_url: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="downloadUrl")] = (
        pydantic.Field(alias="downloadUrl", default=None)
    )
    """
    A presigned URL to download the edited file.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

ProcessorStatus = typing.Union[typing.Literal["PENDING", "PROCESSING", "PROCESSED", "FAILED", "CANCELLED"], typing.Any]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class FileCredits(UncheckedBaseModel):
    """
    These are usage credits for parsing the file.

    This field will not be returned for files processed before October 7, 2025, or for customers on legacy billing systems.

    For more details on how credits work, see our [Credits Guide](/product/general/how-credits-work).
    """

    credits: float = pydantic.Field()
    """
    The number of credits consumed specifically for parsing this file.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class EditRunConfigAdvancedOptions(UncheckedBaseModel):
    """
    Advanced options for the edit operation.
    """

    flatten_pdf: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="flattenPdf")] = pydantic.Field(
        alias="flattenPdf", default=None
    )
    """
    Whether to flatten PDF forms before editing.
    """

    table_parsing_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="tableParsingEnabled")
    ] = pydantic.Field(alias="tableParsingEnabled", default=None)
    """
    Whether to parse tables as arrays.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
